import requests

# https://github.com/bfelbo/DeepMoji/blob/master/emoji_overview.png?raw=true
DEEPMOJI_MAP = {
    0: ":joy:",
    1: ":unamused:",
    2: ":weary:",
    3: ":sob:",
    4: ":heart_eyes:",
    5: ":pensive:",
    6: ":ok_hand:",
    7: ":relaxed:",
    8: ":heart:",
    9: ":smirk:",
    10: ":grin:",
    11: ":notes:",
    12: ":flushed:",
    13: ":100:",
    14: ":sleeping:",
    15: ":relieved:",
    16: ":blush:",
    17: ":raised_hands:",
    18: ":two_hearts:",
    19: ":expressionless:",
    20: ":sweat_smile:",
    21: ":pray:",
    22: ":confused:",
    23: ":kissing_heart:",
    24: ":green_heart:",  # TODO same as 8 ?
    25: ":neutral_face:",
    26: ":information_desk_person:",
    27: ":disappointed:",
    28: ":see_no_evil:",
    29: ":tired_face:",
    30: ":v:",
    31: ":sunglasses:",
    32: ":rage:",
    33: ":+1:",
    34: ":cry:",
    35: ":sleepy:",
    36: ":stuck_out_tongue_closed_eyes:",
    37: ":triumph:",
    38: ":hand:",
    39: ":mask:",
    40: ":wave:",
    41: ":eyes:",
    42: ":gun:",
    43: ":persevere:",
    44: ":smiling_imp:",
    45: ":sweat:",
    46: ":broken_heart:",
    47: ":yellow_heart:",  # TODO same as 8?
    48: ":headphones:",
    49: ":speak_no_evil:",
    50: ":wink:",
    51: ":skull:",
    52: ":confounded:",
    53: ":smile:",
    54: ":stuck_out_tongue_winking_eye:",
    55: ":angry:",
    56: ":no_good:",
    57: ":muscle:",
    58: ":fist:",
    59: ":purple_heart:",
    60: ":sparkling_heart:",
    61: ":blue_heart:",
    62: ":grimacing:",
    63: ":sparkles:"
}

# many thanks to impearker! he hand tagged these emotions
# check his company twitter @avemDNS a website is on the way!
# seriously, check it out
EMOJI_TO_EMOTION = {0: 'Amazement',
                    1: 'Annoyance',
                    2: 'Despair',
                    3: 'Sadness',
                    4: 'Love',
                    5: 'Disappointment',
                    6: 'Optimism',
                    7: 'Joy',
                    8: 'Love',
                    9: 'Bemusement',
                    10: 'Zeal',
                    11: 'Delight',
                    12: 'Subservience',
                    13: 'Awe',
                    14: 'boredom',
                    15: 'Optimism',
                    16: 'Joy',
                    17: 'Delight',
                    18: 'Love',
                    19: 'boredom',
                    20: 'Anxiety',
                    21: 'Pride',
                    22: 'Pessimism',
                    23: 'Love',
                    24: 'Love',
                    25: 'boredom',
                    26: 'Interest',
                    27: 'boredom',
                    28: 'Hope',
                    29: 'Anxiety',
                    30: 'Optimism',
                    31: 'Serenity',
                    32: 'Outrage',
                    33: 'Delight',
                    34: 'Pessimism',
                    35: 'Sadness',
                    36: 'Zeal',
                    37: 'Cynicism',
                    38: 'Dismay',
                    39: 'Wariness',
                    40: 'Unbelief',
                    41: 'Curiosity',
                    42: 'Hatred',
                    43: 'Despair',
                    44: 'Pride',
                    45: 'Contempt',
                    46: 'Despair',
                    47: 'Remorse',
                    48: 'Zeal',
                    49: 'Disfavor',
                    50: 'Zeal',
                    51: 'Morbidness',
                    52: 'Disgust',
                    53: 'Optimism',
                    54: 'Delight',
                    55: 'Annoyance',
                    56: 'Disapproval',
                    57: 'Optimism',
                    58: 'Optimism',
                    59: 'love',
                    60: 'love',
                    61: 'love',
                    62: 'pensiveness',
                    63: 'Joy'}

# https://github.com/words/emoji-emotion/blob/master/faces.txt#L49
# Affin polarity, can be replicated with lilacs.nlp.sentiment_analysis.get_sentiment("your emoji instead of text")
EMOJI_POLARITY = {'100': 3,
                  'angry': -3,
                  'anguished': -3,
                  'astonished': 2,
                  'black_heart': 3,
                  'blue_heart': 3,
                  'blush': 2,
                  'broken_heart': -3,
                  'clap': 3,
                  'clown_face': 0,
                  'cold_sweat': -2,
                  'confounded': -2,
                  'confused': -2,
                  'cowboy_hat_face': 2,
                  'crossed_fingers': 2,
                  'cry': -2,
                  'crying_cat_face': -2,
                  'cupid': 3,
                  'disappointed': -2,
                  'disappointed_relieved': -1,
                  'dizzy_face': -1,
                  'drooling_face': 0,
                  'expressionless': 0,
                  'face_with_thermometer': -1,
                  'fearful': -2,
                  'flushed': -2,
                  'frowning': -1,
                  'frowning_face': -2,
                  'fu': -4,
                  'ghost': -1,
                  'gift_heart': 3,
                  'green_heart': 3,
                  'grimacing': -2,
                  'grin': 2,
                  'grinning': 2,
                  'handshake': 1,
                  'heart': 3,
                  'heart_eyes': 3,
                  'heart_eyes_cat': 3,
                  'heartbeat': 3,
                  'heartpulse': 3,
                  'hugs': 2,
                  'hushed': -1,
                  'imp': -4,
                  'innocent': 3,
                  'joy': 3,
                  'joy_cat': 3,
                  'kiss': 2,
                  'kissing': 2,
                  'kissing_cat': 2,
                  'kissing_closed_eyes': 2,
                  'kissing_heart': 3,
                  'kissing_smiling_eyes': 2,
                  'laughing': 1,
                  'lips': 2,
                  'lying_face': -2,
                  'mask': -1,
                  'money_mouth_face': 0,
                  'nauseated_face': -2,
                  'nerd_face': -1,
                  'neutral_face': 0,
                  'no_mouth': 0,
                  'ok_hand': 2,
                  'open_mouth': -2,
                  'pensive': -1,
                  'persevere': -2,
                  'pouting_cat': -4,
                  'pray': 1,
                  'punch': -1,
                  'purple_heart': 3,
                  'rage': -4,
                  'raised_hands': 4,
                  'relaxed': 2,
                  'relieved': 2,
                  'revolving_hearts': 3,
                  'rofl': 4,
                  'roll_eyes': -1,
                  'scream': -3,
                  'scream_cat': -3,
                  'shit': -3,
                  'skull': -2,
                  'skull_and_crossbones': -2,
                  'sleeping': 0,
                  'sleepy': 0,
                  'slightly_frowning_face': -1,
                  'slightly_smiling_face': 1,
                  'face_with_head_bandage': -2,
                  'sneezing_face': -2,
                  'smile': 2,
                  'smile_cat': 2,
                  'smiley': 2,
                  'smiley_cat': 2,
                  'smiling_imp': -3,
                  'smirk': 2,
                  'smirk_cat': 2,
                  'sob': -3,
                  'sparkling_heart': 3,
                  'stuck_out_tongue': 1,
                  'stuck_out_tongue_closed_eyes': 0,
                  'stuck_out_tongue_winking_eye': -1,
                  'sunglasses': 1,
                  'sweat': -1,
                  'sweat_smile': 2,
                  'thinking': -1,
                  'thumbsdown': -2,
                  'thumbsup': 2,
                  'tired_face': -2,
                  'triumph': 0,
                  'two_hearts': 3,
                  'unamused': -2,
                  'upside_down_face': 0,
                  'v': 2,
                  'weary': -2,
                  'wink': 3,
                  'worried': -3,
                  'yellow_heart': 3,
                  'yum': 3,
                  'zipper_mouth_face': -1}

# https://github.com/wooorm/emoticon/blob/master/support.md
EMOJI_TO_EMOTICON = {
    ':angry:': {'emoji': ' 😠 ',
                'emoticons': [' `>:(`',
                              ' `>:[`',
                              ' `>:-(`',
                              ' `>:-[`',
                              ' `>=(`',
                              ' `>=[`',
                              ' `>=-(`',
                              ' `>=-[` '],
                'tags': [' mad', ' annoyed ']},
    ':blush:': {'emoji': ' 😊 ',
                'emoticons': [' `:")`',
                              ' `:"]`',
                              ' `:"D`',
                              ' `:-")`',
                              ' `:-"]`',
                              ' `:-"D`',
                              ' `=")`',
                              ' `="]`',
                              ' `="D`',
                              ' `=-")`',
                              ' `=-"]`',
                              ' `=-"D` '],
                'tags': [' proud ']},
    ':broken_heart:': {'emoji': ' 💔 ',
                       'emoticons': [' `<\x03`', ' `</3` '],
                       'tags': ['  ']},
    ':confused:': {'emoji': ' 😕 ',
                   'emoticons': [' `:/`',
                                 ' `:\\`',
                                 ' `:-/`',
                                 ' `:-\\`',
                                 ' `=/`',
                                 ' `=\\`',
                                 ' `=-/`',
                                 ' `=-\\` '],
                   'tags': ['  ']},
    ':frowning:': {'emoji': ' 😦 ',
                   'emoticons': [' `:(`',
                                 ' `:[`',
                                 ' `:-(`',
                                 ' `:-[`',
                                 ' `=(`',
                                 ' `=[`',
                                 ' `=-(`',
                                 ' `=-[` '],
                   'tags': ['  ']},
    ':heart:': {'emoji': ' ❤️ ', 'emoticons': [' `<3` '], 'tags': [' love ']},
    ':imp:': {'emoji': ' 👿 ',
              'emoticons': [' `]:(`',
                            ' `]:[`',
                            ' `]:-(`',
                            ' `]:-[`',
                            ' `]=(`',
                            ' `]=[`',
                            ' `]=-(`',
                            ' `]=-[` '],
              'tags': [' angry', ' devil', ' evil', ' horns ']},
    ':innocent:': {'emoji': ' 😇 ',
                   'emoticons': [' `o:)`',
                                 ' `o:]`',
                                 ' `o:D`',
                                 ' `o:-)`',
                                 ' `o:-]`',
                                 ' `o:-D`',
                                 ' `o=)`',
                                 ' `o=]`',
                                 ' `o=D`',
                                 ' `o=-)`',
                                 ' `o=-]`',
                                 ' `o=-D`',
                                 ' `O:)`',
                                 ' `O:]`',
                                 ' `O:D`',
                                 ' `O:-)`',
                                 ' `O:-]`',
                                 ' `O:-D`',
                                 ' `O=)`',
                                 ' `O=]`',
                                 ' `O=D`',
                                 ' `O=-)`',
                                 ' `O=-]`',
                                 ' `O=-D`',
                                 ' `0:)`',
                                 ' `0:]`',
                                 ' `0:D`',
                                 ' `0:-)`',
                                 ' `0:-]`',
                                 ' `0:-D`',
                                 ' `0=)`',
                                 ' `0=]`',
                                 ' `0=D`',
                                 ' `0=-)`',
                                 ' `0=-]`',
                                 ' `0=-D` '],
                   'tags': [' angel ']},
    ':joy:': {'emoji': ' 😂 ',
              'emoticons': [' `:,)`',
                            ' `:,]`',
                            ' `:,D`',
                            ' `:,-)`',
                            ' `:,-]`',
                            ' `:,-D`',
                            " `:')`",
                            " `:']`",
                            " `:'D`",
                            " `:'-)`",
                            " `:'-]`",
                            " `:'-D`",
                            ' `=,)`',
                            ' `=,]`',
                            ' `=,D`',
                            ' `=,-)`',
                            ' `=,-]`',
                            ' `=,-D`',
                            " `=')`",
                            " `=']`",
                            " `='D`",
                            " `='-)`",
                            " `='-]`",
                            " `='-D` "],
              'tags': [' tears ']},
    ':kissing:': {'emoji': ' 😗 ',
                  'emoticons': [' `:*`', ' `:-*`', ' `=*`', ' `=-*` '],
                  'tags': ['  ']},
    ':laughing:': {'emoji': ' 😆 ',
                   'emoticons': [' `x)`',
                                 ' `x]`',
                                 ' `xD`',
                                 ' `x-)`',
                                 ' `x-]`',
                                 ' `x-D`',
                                 ' `X)`',
                                 ' `X]`',
                                 ' `X-)`',
                                 ' `X-]`',
                                 ' `X-D` '],
                   'tags': [' happy', ' haha ']},
    ':man:': {'emoji': ' 👨 ',
              'emoticons': [' `:3`',
                            ' `:-3`',
                            ' `=3`',
                            ' `=-3`',
                            ' `',
                            '3`',
                            ' `',
                            '-3`',
                            ' `x3`',
                            ' `x-3`',
                            ' `X3`',
                            ' `X-3` '],
              'tags': [' mustache', ' father', ' dad ']},
    ':no_mouth:': {'emoji': ' 😶 ',
                   'emoticons': [' `:-` '],
                   'tags': [' mute', ' silence ']},
    ':open_mouth:': {'emoji': ' 😮 ',
                     'emoticons': [' `:o`',
                                   ' `:O`',
                                   ' `:0`',
                                   ' `:-o`',
                                   ' `:-O`',
                                   ' `:-0`',
                                   ' `=o`',
                                   ' `=O`',
                                   ' `=0`',
                                   ' `=-o`',
                                   ' `=-O`',
                                   ' `=-0` '],
                     'tags': [' surprise', ' impressed', ' wow ']},
    ':rage:': {'emoji': ' 😡 ',
               'emoticons': [' `:@`', ' `:-@`', ' `=@`', ' `=-@` '],
               'tags': [' angry ']},
    ':smile:': {'emoji': ' 😄 ',
                'emoticons': [' `:D`', ' `:-D`', ' `=D`', ' `=-D` '],
                'tags': [' happy', ' joy', ' laugh', ' pleased ']},
    ':smiley:': {'emoji': ' 😃 ',
                 'emoticons': [' `:)`',
                               ' `:]`',
                               ' `:-)`',
                               ' `:-]`',
                               ' `=)`',
                               ' `=]`',
                               ' `=-)`',
                               ' `=-]` '],
                 'tags': [' happy', ' joy', ' haha ']},
    ':smiling_imp:': {'emoji': ' 😈 ',
                      'emoticons': [' `]:)`',
                                    ' `]:]`',
                                    ' `]:D`',
                                    ' `]:-)`',
                                    ' `]:-]`',
                                    ' `]:-D`',
                                    ' `]=)`',
                                    ' `]=]`',
                                    ' `]=D`',
                                    ' `]=-)`',
                                    ' `]=-]`',
                                    ' `]=-D` '],
                      'tags': [' devil', ' evil', ' horns ']},
    ':sob:': {'emoji': ' 😭 ',
              'emoticons': [" `:,'(`",
                            " `:,'[`",
                            " `:,'-(`",
                            " `:,'-[`",
                            " `:',(`",
                            " `:',[`",
                            " `:',-(`",
                            " `:',-[`",
                            " `=,'(`",
                            " `=,'[`",
                            " `=,'-(`",
                            " `=,'-[`",
                            " `=',(`",
                            " `=',[`",
                            " `=',-(`",
                            " `=',-[` "],
              'tags': [' sad', ' cry', ' bawling ']},
    ':stuck_out_tongue:': {'emoji': ' 😛 ',
                           'emoticons': [' `:p`',
                                         ' `:P`',
                                         ' `:d`',
                                         ' `:-p`',
                                         ' `:-P`',
                                         ' `:-d`',
                                         ' `=p`',
                                         ' `=P`',
                                         ' `=d`',
                                         ' `=-p`',
                                         ' `=-P`',
                                         ' `=-d` '],
                           'tags': ['  ']},
    ':stuck_out_tongue_closed_eyes:': {'emoji': ' 😝 ',
                                       'emoticons': [' `xP`',
                                                     ' `x-p`',
                                                     ' `x-P`',
                                                     ' `x-d`',
                                                     ' `Xp`',
                                                     ' `Xd`',
                                                     ' `X-p`',
                                                     ' `X-P`',
                                                     ' `X-d` '],
                                       'tags': [' prank ']},
    ':stuck_out_tongue_winking_eye:': {'emoji': ' 😜 ',
                                       'emoticons': [' `',
                                                     'p`',
                                                     ' `',
                                                     'P`',
                                                     ' `',
                                                     'd`',
                                                     ' `',
                                                     '-p`',
                                                     ' `',
                                                     '-P`',
                                                     ' `',
                                                     '-d` '],
                                       'tags': [' prank', ' silly ']},
    ':sunglasses:': {'emoji': ' 😎 ',
                     'emoticons': [' `8)`',
                                   ' `8]`',
                                   ' `8D`',
                                   ' `8-)`',
                                   ' `8-]`',
                                   ' `8-D`',
                                   ' `B)`',
                                   ' `B]`',
                                   ' `B-)`',
                                   ' `B-]`',
                                   ' `B-D` '],
                     'tags': [' cool ']},
    ':sweat:': {'emoji': ' 😓 ',
                'emoticons': [' `,:(`',
                              ' `,:[`',
                              ' `,:-(`',
                              ' `,:-[`',
                              ' `,=(`',
                              ' `,=[`',
                              ' `,=-(`',
                              ' `,=-[`',
                              " `':(`",
                              " `':[`",
                              " `':-(`",
                              " `':-[`",
                              " `'=(`",
                              " `'=[`",
                              " `'=-(`",
                              " `'=-[` "],
                'tags': ['  ']},
    ':sweat_smile:': {'emoji': ' 😅 ',
                      'emoticons': [' `,:)`',
                                    ' `,:]`',
                                    ' `,:D`',
                                    ' `,:-)`',
                                    ' `,:-]`',
                                    ' `,:-D`',
                                    ' `,=)`',
                                    ' `,=]`',
                                    ' `,=D`',
                                    ' `,=-)`',
                                    ' `,=-]`',
                                    ' `,=-D`',
                                    " `':)`",
                                    " `':]`",
                                    " `':D`",
                                    " `':-)`",
                                    " `':-]`",
                                    " `':-D`",
                                    " `'=)`",
                                    " `'=]`",
                                    " `'=D`",
                                    " `'=-)`",
                                    " `'=-]`",
                                    " `'=-D` "],
                      'tags': [' hot ']},
    ':unamused:': {'emoji': ' 😒 ',
                   'emoticons': [' `:$`',
                                 ' `:s`',
                                 ' `:z`',
                                 ' `:S`',
                                 ' `:Z`',
                                 ' `:-$`',
                                 ' `:-s`',
                                 ' `:-z`',
                                 ' `:-S`',
                                 ' `:-Z`',
                                 ' `=$`',
                                 ' `=s`',
                                 ' `=z`',
                                 ' `=S`',
                                 ' `=Z`',
                                 ' `=-$`',
                                 ' `=-s`',
                                 ' `=-z`',
                                 ' `=-S`',
                                 ' `=-Z` '],
                   'tags': [' meh ']},
    ':wink:': {'emoji': ' 😉 ',
               'emoticons': [' `',
                             ')`',
                             ' `',
                             ']`',
                             ' `',
                             'D`',
                             ' `',
                             '-)`',
                             ' `',
                             '-]`',
                             ' `',
                             '-D` '],
               'tags': [' flirt ']}}

# https://github.com/wooorm/gemoji/blob/master/support.md
EMOJI_DATA = {':+1:': {'emoji': ' 👍 ', 'tags': ['approve', 'ok']},
              ':-1:': {'emoji': ' 👎 ', 'tags': ['disapprove', 'bury']},
              ':100:': {'emoji': ' 💯 ', 'tags': ['score', 'perfect']},
              ':1234:': {'emoji': ' 🔢 ', 'tags': ['numbers']},
              ':1st_place_medal:': {'emoji': ' \U0001f947 ', 'tags': ['gold']},
              ':2nd_place_medal:': {'emoji': ' \U0001f948 ', 'tags': ['silver']},
              ':3rd_place_medal:': {'emoji': ' \U0001f949 ', 'tags': ['bronze']},
              ':8ball:': {'emoji': ' 🎱 ', 'tags': ['pool', 'billiards']},
              ':a:': {'emoji': ' 🅰️ ', 'tags': []},
              ':ab:': {'emoji': ' 🆎 ', 'tags': []},
              ':abc:': {'emoji': ' 🔤 ', 'tags': ['alphabet']},
              ':abcd:': {'emoji': ' 🔡 ', 'tags': []},
              ':accept:': {'emoji': ' 🉑 ', 'tags': []},
              ':aerial_tramway:': {'emoji': ' 🚡 ', 'tags': []},
              ':afghanistan:': {'emoji': ' 🇦🇫 ', 'tags': []},
              ':airplane:': {'emoji': ' ✈️ ', 'tags': ['flight']},
              ':aland_islands:': {'emoji': ' 🇦🇽 ', 'tags': []},
              ':alarm_clock:': {'emoji': ' ⏰ ', 'tags': ['morning']},
              ':albania:': {'emoji': ' 🇦🇱 ', 'tags': []},
              ':alembic:': {'emoji': ' ⚗️ ', 'tags': []},
              ':algeria:': {'emoji': ' 🇩🇿 ', 'tags': []},
              ':alien:': {'emoji': ' 👽 ', 'tags': ['ufo']},
              ':ambulance:': {'emoji': ' 🚑 ', 'tags': []},
              ':american_samoa:': {'emoji': ' 🇦🇸 ', 'tags': []},
              ':amphora:': {'emoji': ' 🏺 ', 'tags': []},
              ':anchor:': {'emoji': ' ⚓️ ', 'tags': ['ship']},
              ':andorra:': {'emoji': ' 🇦🇩 ', 'tags': []},
              ':angel:': {'emoji': ' 👼 ', 'tags': []},
              ':anger:': {'emoji': ' 💢 ', 'tags': ['angry']},
              ':angola:': {'emoji': ' 🇦🇴 ', 'tags': []},
              ':angry:': {'emoji': ' 😠 ', 'tags': ['mad', 'annoyed']},
              ':anguilla:': {'emoji': ' 🇦🇮 ', 'tags': []},
              ':anguished:': {'emoji': ' 😧 ', 'tags': ['stunned']},
              ':ant:': {'emoji': ' 🐜 ', 'tags': []},
              ':antarctica:': {'emoji': ' 🇦🇶 ', 'tags': []},
              ':antigua_barbuda:': {'emoji': ' 🇦🇬 ', 'tags': []},
              ':apple:': {'emoji': ' 🍎 ', 'tags': []},
              ':aquarius:': {'emoji': ' ♒️ ', 'tags': []},
              ':argentina:': {'emoji': ' 🇦🇷 ', 'tags': []},
              ':aries:': {'emoji': ' ♈️ ', 'tags': []},
              ':armenia:': {'emoji': ' 🇦🇲 ', 'tags': []},
              ':arrow_backward:': {'emoji': ' ◀️ ', 'tags': []},
              ':arrow_double_down:': {'emoji': ' ⏬ ', 'tags': []},
              ':arrow_double_up:': {'emoji': ' ⏫ ', 'tags': []},
              ':arrow_down:': {'emoji': ' ⬇️ ', 'tags': []},
              ':arrow_down_small:': {'emoji': ' 🔽 ', 'tags': []},
              ':arrow_forward:': {'emoji': ' ▶️ ', 'tags': []},
              ':arrow_heading_down:': {'emoji': ' ⤵️ ', 'tags': []},
              ':arrow_heading_up:': {'emoji': ' ⤴️ ', 'tags': []},
              ':arrow_left:': {'emoji': ' ⬅️ ', 'tags': []},
              ':arrow_lower_left:': {'emoji': ' ↙️ ', 'tags': []},
              ':arrow_lower_right:': {'emoji': ' ↘️ ', 'tags': []},
              ':arrow_right:': {'emoji': ' ➡️ ', 'tags': []},
              ':arrow_right_hook:': {'emoji': ' ↪️ ', 'tags': []},
              ':arrow_up:': {'emoji': ' ⬆️ ', 'tags': []},
              ':arrow_up_down:': {'emoji': ' ↕️ ', 'tags': []},
              ':arrow_up_small:': {'emoji': ' 🔼 ', 'tags': []},
              ':arrow_upper_left:': {'emoji': ' ↖️ ', 'tags': []},
              ':arrow_upper_right:': {'emoji': ' ↗️ ', 'tags': []},
              ':arrows_clockwise:': {'emoji': ' 🔃 ', 'tags': []},
              ':arrows_counterclockwise:': {'emoji': ' 🔄 ', 'tags': ['sync']},
              ':art:': {'emoji': ' 🎨 ', 'tags': ['design', 'paint']},
              ':articulated_lorry:': {'emoji': ' 🚛 ', 'tags': []},
              ':artificial_satellite:': {'emoji': ' 🛰 ', 'tags': ['orbit', 'space']},
              ':aruba:': {'emoji': ' 🇦🇼 ', 'tags': []},
              ':asterisk:': {'emoji': ' \\*️⃣ ', 'tags': []},
              ':astonished:': {'emoji': ' 😲 ', 'tags': ['amazed', 'gasp']},
              ':athletic_shoe:': {'emoji': ' 👟 ', 'tags': ['sneaker', 'sport', 'running']},
              ':atm:': {'emoji': ' 🏧 ', 'tags': []},
              ':atom_symbol:': {'emoji': ' ⚛️ ', 'tags': []},
              ':australia:': {'emoji': ' 🇦🇺 ', 'tags': []},
              ':austria:': {'emoji': ' 🇦🇹 ', 'tags': []},
              ':avocado:': {'emoji': ' \U0001f951 ', 'tags': []},
              ':azerbaijan:': {'emoji': ' 🇦🇿 ', 'tags': []},
              ':b:': {'emoji': ' 🅱️ ', 'tags': []},
              ':baby:': {'emoji': ' 👶 ', 'tags': ['child', 'newborn']},
              ':baby_bottle:': {'emoji': ' 🍼 ', 'tags': ['milk']},
              ':baby_chick:': {'emoji': ' 🐤 ', 'tags': []},
              ':baby_symbol:': {'emoji': ' 🚼 ', 'tags': []},
              ':back:': {'emoji': ' 🔙 ', 'tags': []},
              ':bacon:': {'emoji': ' \U0001f953 ', 'tags': []},
              ':badminton:': {'emoji': ' 🏸 ', 'tags': []},
              ':baggage_claim:': {'emoji': ' 🛄 ', 'tags': ['airport']},
              ':baguette_bread:': {'emoji': ' \U0001f956 ', 'tags': []},
              ':bahamas:': {'emoji': ' 🇧🇸 ', 'tags': []},
              ':bahrain:': {'emoji': ' 🇧🇭 ', 'tags': []},
              ':balance_scale:': {'emoji': ' ⚖️ ', 'tags': []},
              ':balloon:': {'emoji': ' 🎈 ', 'tags': ['party', 'birthday']},
              ':ballot_box:': {'emoji': ' 🗳 ', 'tags': []},
              ':ballot_box_with_check:': {'emoji': ' ☑️ ', 'tags': []},
              ':bamboo:': {'emoji': ' 🎍 ', 'tags': []},
              ':banana:': {'emoji': ' 🍌 ', 'tags': ['fruit']},
              ':bangbang:': {'emoji': ' ‼️ ', 'tags': []},
              ':bangladesh:': {'emoji': ' 🇧🇩 ', 'tags': []},
              ':bank:': {'emoji': ' 🏦 ', 'tags': []},
              ':bar_chart:': {'emoji': ' 📊 ', 'tags': ['stats', 'metrics']},
              ':barbados:': {'emoji': ' 🇧🇧 ', 'tags': []},
              ':barber:': {'emoji': ' 💈 ', 'tags': []},
              ':baseball:': {'emoji': ' ⚾️ ', 'tags': ['sports']},
              ':basketball:': {'emoji': ' 🏀 ', 'tags': ['sports']},
              ':basketball_man:': {'emoji': ' ⛹ ', 'tags': []},
              ':basketball_woman:': {'emoji': ' ⛹️\u200d♀️ ', 'tags': []},
              ':bat:': {'emoji': ' \U0001f987 ', 'tags': []},
              ':bath:': {'emoji': ' 🛀 ', 'tags': ['shower']},
              ':bathtub:': {'emoji': ' 🛁 ', 'tags': []},
              ':battery:': {'emoji': ' 🔋 ', 'tags': ['power']},
              ':beach_umbrella:': {'emoji': ' 🏖 ', 'tags': []},
              ':bear:': {'emoji': ' 🐻 ', 'tags': []},
              ':bed:': {'emoji': ' 🛏 ', 'tags': []},
              ':bee:': {'emoji': ' 🐝 ', 'tags': []},
              ':beer:': {'emoji': ' 🍺 ', 'tags': ['drink']},
              ':beers:': {'emoji': ' 🍻 ', 'tags': ['drinks']},
              ':beetle:': {'emoji': ' 🐞 ', 'tags': ['bug']},
              ':beginner:': {'emoji': ' 🔰 ', 'tags': []},
              ':belarus:': {'emoji': ' 🇧🇾 ', 'tags': []},
              ':belgium:': {'emoji': ' 🇧🇪 ', 'tags': []},
              ':belize:': {'emoji': ' 🇧🇿 ', 'tags': []},
              ':bell:': {'emoji': ' 🔔 ', 'tags': ['sound', 'notification']},
              ':bellhop_bell:': {'emoji': ' 🛎 ', 'tags': []},
              ':benin:': {'emoji': ' 🇧🇯 ', 'tags': []},
              ':bento:': {'emoji': ' 🍱 ', 'tags': []},
              ':bermuda:': {'emoji': ' 🇧🇲 ', 'tags': []},
              ':bhutan:': {'emoji': ' 🇧🇹 ', 'tags': []},
              ':bicyclist:': {'emoji': ' 🚴 ', 'tags': []},
              ':bike:': {'emoji': ' 🚲 ', 'tags': ['bicycle']},
              ':biking_man:': {'emoji': ' 🚴 ', 'tags': []},
              ':biking_woman:': {'emoji': ' 🚴\u200d♀ ', 'tags': []},
              ':bikini:': {'emoji': ' 👙 ', 'tags': ['beach']},
              ':biohazard:': {'emoji': ' ☣️ ', 'tags': []},
              ':bird:': {'emoji': ' 🐦 ', 'tags': []},
              ':birthday:': {'emoji': ' 🎂 ', 'tags': ['party']},
              ':black_circle:': {'emoji': ' ⚫️ ', 'tags': []},
              ':black_flag:': {'emoji': ' 🏴 ', 'tags': []},
              ':black_heart:': {'emoji': ' \U0001f5a4 ', 'tags': []},
              ':black_joker:': {'emoji': ' 🃏 ', 'tags': []},
              ':black_large_square:': {'emoji': ' ⬛️ ', 'tags': []},
              ':black_medium_small_square:': {'emoji': ' ◾️ ', 'tags': []},
              ':black_medium_square:': {'emoji': ' ◼️ ', 'tags': []},
              ':black_nib:': {'emoji': ' ✒️ ', 'tags': []},
              ':black_small_square:': {'emoji': ' ▪️ ', 'tags': []},
              ':black_square_button:': {'emoji': ' 🔲 ', 'tags': []},
              ':blonde_man:': {'emoji': ' 👱 ', 'tags': ['boy']},
              ':blonde_woman:': {'emoji': ' 👱\u200d♀ ', 'tags': []},
              ':blossom:': {'emoji': ' 🌼 ', 'tags': []},
              ':blowfish:': {'emoji': ' 🐡 ', 'tags': []},
              ':blue_book:': {'emoji': ' 📘 ', 'tags': []},
              ':blue_car:': {'emoji': ' 🚙 ', 'tags': []},
              ':blue_heart:': {'emoji': ' 💙 ', 'tags': []},
              ':blush:': {'emoji': ' 😊 ', 'tags': ['proud']},
              ':boar:': {'emoji': ' 🐗 ', 'tags': []},
              ':boat:': {'emoji': ' ⛵️ ', 'tags': []},
              ':bolivia:': {'emoji': ' 🇧🇴 ', 'tags': []},
              ':bomb:': {'emoji': ' 💣 ', 'tags': ['boom']},
              ':book:': {'emoji': ' 📖 ', 'tags': []},
              ':bookmark:': {'emoji': ' 🔖 ', 'tags': []},
              ':bookmark_tabs:': {'emoji': ' 📑 ', 'tags': []},
              ':books:': {'emoji': ' 📚 ', 'tags': ['library']},
              ':boom:': {'emoji': ' 💥 ', 'tags': ['explode']},
              ':boot:': {'emoji': ' 👢 ', 'tags': []},
              ':bosnia_herzegovina:': {'emoji': ' 🇧🇦 ', 'tags': []},
              ':botswana:': {'emoji': ' 🇧🇼 ', 'tags': []},
              ':bouquet:': {'emoji': ' 💐 ', 'tags': ['flowers']},
              ':bow:': {'emoji': ' 🙇 ', 'tags': ['respect', 'thanks']},
              ':bow_and_arrow:': {'emoji': ' 🏹 ', 'tags': ['archery']},
              ':bowing_man:': {'emoji': ' 🙇 ', 'tags': ['respect', 'thanks']},
              ':bowing_woman:': {'emoji': ' 🙇\u200d♀ ', 'tags': ['respect', 'thanks']},
              ':bowling:': {'emoji': ' 🎳 ', 'tags': []},
              ':boxing_glove:': {'emoji': ' \U0001f94a ', 'tags': []},
              ':boy:': {'emoji': ' 👦 ', 'tags': ['child']},
              ':brazil:': {'emoji': ' 🇧🇷 ', 'tags': []},
              ':bread:': {'emoji': ' 🍞 ', 'tags': ['toast']},
              ':bride_with_veil:': {'emoji': ' 👰 ', 'tags': ['marriage', 'wedding']},
              ':bridge_at_night:': {'emoji': ' 🌉 ', 'tags': []},
              ':briefcase:': {'emoji': ' 💼 ', 'tags': ['business']},
              ':british_indian_ocean_territory:': {'emoji': ' 🇮🇴 ', 'tags': []},
              ':british_virgin_islands:': {'emoji': ' 🇻🇬 ', 'tags': []},
              ':broken_heart:': {'emoji': ' 💔 ', 'tags': []},
              ':brunei:': {'emoji': ' 🇧🇳 ', 'tags': []},
              ':bug:': {'emoji': ' 🐛 ', 'tags': []},
              ':building_construction:': {'emoji': ' 🏗 ', 'tags': []},
              ':bulb:': {'emoji': ' 💡 ', 'tags': ['idea', 'light']},
              ':bulgaria:': {'emoji': ' 🇧🇬 ', 'tags': []},
              ':bullettrain_front:': {'emoji': ' 🚅 ', 'tags': ['train']},
              ':bullettrain_side:': {'emoji': ' 🚄 ', 'tags': ['train']},
              ':burkina_faso:': {'emoji': ' 🇧🇫 ', 'tags': []},
              ':burrito:': {'emoji': ' 🌯 ', 'tags': []},
              ':burundi:': {'emoji': ' 🇧🇮 ', 'tags': []},
              ':bus:': {'emoji': ' 🚌 ', 'tags': []},
              ':business_suit_levitating:': {'emoji': ' 🕴 ', 'tags': []},
              ':busstop:': {'emoji': ' 🚏 ', 'tags': []},
              ':bust_in_silhouette:': {'emoji': ' 👤 ', 'tags': ['user']},
              ':busts_in_silhouette:': {'emoji': ' 👥 ', 'tags': ['users', 'group', 'team']},
              ':butterfly:': {'emoji': ' \U0001f98b ', 'tags': []},
              ':cactus:': {'emoji': ' 🌵 ', 'tags': []},
              ':cake:': {'emoji': ' 🍰 ', 'tags': ['dessert']},
              ':calendar:': {'emoji': ' 📆 ', 'tags': ['schedule']},
              ':call_me_hand:': {'emoji': ' \U0001f919 ', 'tags': []},
              ':calling:': {'emoji': ' 📲 ', 'tags': ['call', 'incoming']},
              ':cambodia:': {'emoji': ' 🇰🇭 ', 'tags': []},
              ':camel:': {'emoji': ' 🐫 ', 'tags': []},
              ':camera:': {'emoji': ' 📷 ', 'tags': ['photo']},
              ':camera_flash:': {'emoji': ' 📸 ', 'tags': ['photo']},
              ':cameroon:': {'emoji': ' 🇨🇲 ', 'tags': []},
              ':camping:': {'emoji': ' 🏕 ', 'tags': []},
              ':canada:': {'emoji': ' 🇨🇦 ', 'tags': []},
              ':canary_islands:': {'emoji': ' 🇮🇨 ', 'tags': []},
              ':cancer:': {'emoji': ' ♋️ ', 'tags': []},
              ':candle:': {'emoji': ' 🕯 ', 'tags': []},
              ':candy:': {'emoji': ' 🍬 ', 'tags': ['sweet']},
              ':canoe:': {'emoji': ' \U0001f6f6 ', 'tags': []},
              ':cape_verde:': {'emoji': ' 🇨🇻 ', 'tags': []},
              ':capital_abcd:': {'emoji': ' 🔠 ', 'tags': ['letters']},
              ':capricorn:': {'emoji': ' ♑️ ', 'tags': []},
              ':car:': {'emoji': ' 🚗 ', 'tags': []},
              ':card_file_box:': {'emoji': ' 🗃 ', 'tags': []},
              ':card_index:': {'emoji': ' 📇 ', 'tags': []},
              ':card_index_dividers:': {'emoji': ' 🗂 ', 'tags': []},
              ':caribbean_netherlands:': {'emoji': ' 🇧🇶 ', 'tags': []},
              ':carousel_horse:': {'emoji': ' 🎠 ', 'tags': []},
              ':carrot:': {'emoji': ' \U0001f955 ', 'tags': []},
              ':cat2:': {'emoji': ' 🐈 ', 'tags': []},
              ':cat:': {'emoji': ' 🐱 ', 'tags': ['pet']},
              ':cayman_islands:': {'emoji': ' 🇰🇾 ', 'tags': []},
              ':cd:': {'emoji': ' 💿 ', 'tags': []},
              ':central_african_republic:': {'emoji': ' 🇨🇫 ', 'tags': []},
              ':chad:': {'emoji': ' 🇹🇩 ', 'tags': []},
              ':chains:': {'emoji': ' ⛓ ', 'tags': []},
              ':champagne:': {'emoji': ' 🍾 ', 'tags': ['bottle', 'bubbly', 'celebration']},
              ':chart:': {'emoji': ' 💹 ', 'tags': []},
              ':chart_with_downwards_trend:': {'emoji': ' 📉 ', 'tags': ['graph', 'metrics']},
              ':chart_with_upwards_trend:': {'emoji': ' 📈 ', 'tags': ['graph', 'metrics']},
              ':checkered_flag:': {'emoji': ' 🏁 ', 'tags': ['milestone', 'finish']},
              ':cheese:': {'emoji': ' 🧀 ', 'tags': []},
              ':cherries:': {'emoji': ' 🍒 ', 'tags': ['fruit']},
              ':cherry_blossom:': {'emoji': ' 🌸 ', 'tags': ['flower', 'spring']},
              ':chestnut:': {'emoji': ' 🌰 ', 'tags': []},
              ':chicken:': {'emoji': ' 🐔 ', 'tags': []},
              ':children_crossing:': {'emoji': ' 🚸 ', 'tags': []},
              ':chile:': {'emoji': ' 🇨🇱 ', 'tags': []},
              ':chipmunk:': {'emoji': ' 🐿 ', 'tags': []},
              ':chocolate_bar:': {'emoji': ' 🍫 ', 'tags': []},
              ':christmas_island:': {'emoji': ' 🇨🇽 ', 'tags': []},
              ':christmas_tree:': {'emoji': ' 🎄 ', 'tags': []},
              ':church:': {'emoji': ' ⛪️ ', 'tags': []},
              ':cinema:': {'emoji': ' 🎦 ', 'tags': ['film', 'movie']},
              ':circus_tent:': {'emoji': ' 🎪 ', 'tags': []},
              ':city_sunrise:': {'emoji': ' 🌇 ', 'tags': []},
              ':city_sunset:': {'emoji': ' 🌆 ', 'tags': []},
              ':cityscape:': {'emoji': ' 🏙 ', 'tags': ['skyline']},
              ':cl:': {'emoji': ' 🆑 ', 'tags': []},
              ':clamp:': {'emoji': ' 🗜 ', 'tags': []},
              ':clap:': {'emoji': ' 👏 ', 'tags': ['praise', 'applause']},
              ':clapper:': {'emoji': ' 🎬 ', 'tags': ['film']},
              ':classical_building:': {'emoji': ' 🏛 ', 'tags': []},
              ':clinking_glasses:': {'emoji': ' \U0001f942 ', 'tags': ['cheers', 'toast']},
              ':clipboard:': {'emoji': ' 📋 ', 'tags': []},
              ':clock1030:': {'emoji': ' 🕥 ', 'tags': []},
              ':clock10:': {'emoji': ' 🕙 ', 'tags': []},
              ':clock1130:': {'emoji': ' 🕦 ', 'tags': []},
              ':clock11:': {'emoji': ' 🕚 ', 'tags': []},
              ':clock1230:': {'emoji': ' 🕧 ', 'tags': []},
              ':clock12:': {'emoji': ' 🕛 ', 'tags': []},
              ':clock130:': {'emoji': ' 🕜 ', 'tags': []},
              ':clock1:': {'emoji': ' 🕐 ', 'tags': []},
              ':clock230:': {'emoji': ' 🕝 ', 'tags': []},
              ':clock2:': {'emoji': ' 🕑 ', 'tags': []},
              ':clock330:': {'emoji': ' 🕞 ', 'tags': []},
              ':clock3:': {'emoji': ' 🕒 ', 'tags': []},
              ':clock430:': {'emoji': ' 🕟 ', 'tags': []},
              ':clock4:': {'emoji': ' 🕓 ', 'tags': []},
              ':clock530:': {'emoji': ' 🕠 ', 'tags': []},
              ':clock5:': {'emoji': ' 🕔 ', 'tags': []},
              ':clock630:': {'emoji': ' 🕡 ', 'tags': []},
              ':clock6:': {'emoji': ' 🕕 ', 'tags': []},
              ':clock730:': {'emoji': ' 🕢 ', 'tags': []},
              ':clock7:': {'emoji': ' 🕖 ', 'tags': []},
              ':clock830:': {'emoji': ' 🕣 ', 'tags': []},
              ':clock8:': {'emoji': ' 🕗 ', 'tags': []},
              ':clock930:': {'emoji': ' 🕤 ', 'tags': []},
              ':clock9:': {'emoji': ' 🕘 ', 'tags': []},
              ':closed_book:': {'emoji': ' 📕 ', 'tags': []},
              ':closed_lock_with_key:': {'emoji': ' 🔐 ', 'tags': ['security']},
              ':closed_umbrella:': {'emoji': ' 🌂 ', 'tags': ['weather', 'rain']},
              ':cloud:': {'emoji': ' ☁️ ', 'tags': []},
              ':cloud_with_lightning:': {'emoji': ' 🌩 ', 'tags': []},
              ':cloud_with_lightning_and_rain:': {'emoji': ' ⛈ ', 'tags': []},
              ':cloud_with_rain:': {'emoji': ' 🌧 ', 'tags': []},
              ':cloud_with_snow:': {'emoji': ' 🌨 ', 'tags': []},
              ':clown_face:': {'emoji': ' \U0001f921 ', 'tags': []},
              ':clubs:': {'emoji': ' ♣️ ', 'tags': []},
              ':cn:': {'emoji': ' 🇨🇳 ', 'tags': ['china']},
              ':cocktail:': {'emoji': ' 🍸 ', 'tags': ['drink']},
              ':cocos_islands:': {'emoji': ' 🇨🇨 ', 'tags': ['keeling']},
              ':coffee:': {'emoji': ' ☕️ ', 'tags': ['cafe', 'espresso']},
              ':coffin:': {'emoji': ' ⚰️ ', 'tags': ['funeral']},
              ':cold_sweat:': {'emoji': ' 😰 ', 'tags': ['nervous']},
              ':collision:': {'emoji': ' 💥 ', 'tags': ['explode']},
              ':colombia:': {'emoji': ' 🇨🇴 ', 'tags': []},
              ':comet:': {'emoji': ' ☄ ', 'tags': []},
              ':comoros:': {'emoji': ' 🇰🇲 ', 'tags': []},
              ':computer:': {'emoji': ' 💻 ', 'tags': ['desktop', 'screen']},
              ':computer_mouse:': {'emoji': ' 🖱 ', 'tags': []},
              ':confetti_ball:': {'emoji': ' 🎊 ', 'tags': []},
              ':confounded:': {'emoji': ' 😖 ', 'tags': []},
              ':confused:': {'emoji': ' 😕 ', 'tags': []},
              ':congo_brazzaville:': {'emoji': ' 🇨🇬 ', 'tags': []},
              ':congo_kinshasa:': {'emoji': ' 🇨🇩 ', 'tags': []},
              ':congratulations:': {'emoji': ' ㊗️ ', 'tags': []},
              ':construction:': {'emoji': ' 🚧 ', 'tags': ['wip']},
              ':construction_worker:': {'emoji': ' 👷 ', 'tags': ['helmet']},
              ':construction_worker_man:': {'emoji': ' 👷 ', 'tags': ['helmet']},
              ':construction_worker_woman:': {'emoji': ' 👷\u200d♀ ', 'tags': []},
              ':control_knobs:': {'emoji': ' 🎛 ', 'tags': []},
              ':convenience_store:': {'emoji': ' 🏪 ', 'tags': []},
              ':cook_islands:': {'emoji': ' 🇨🇰 ', 'tags': []},
              ':cookie:': {'emoji': ' 🍪 ', 'tags': []},
              ':cool:': {'emoji': ' 🆒 ', 'tags': []},
              ':cop:': {'emoji': ' 👮 ', 'tags': ['police', 'law']},
              ':copyright:': {'emoji': ' ©️ ', 'tags': []},
              ':corn:': {'emoji': ' 🌽 ', 'tags': []},
              ':costa_rica:': {'emoji': ' 🇨🇷 ', 'tags': []},
              ':cote_divoire:': {'emoji': ' 🇨🇮 ', 'tags': ['ivory']},
              ':couch_and_lamp:': {'emoji': ' 🛋 ', 'tags': []},
              ':couple:': {'emoji': ' 👫 ', 'tags': ['date']},
              ':couple_with_heart:': {'emoji': ' 💑 ', 'tags': []},
              ':couple_with_heart_man_man:': {'emoji': ' 👨\u200d❤️\u200d👨 ', 'tags': []},
              ':couple_with_heart_woman_man:': {'emoji': ' 💑 ', 'tags': []},
              ':couple_with_heart_woman_woman:': {'emoji': ' 👩\u200d❤️\u200d👩 ', 'tags': []},
              ':couplekiss_man_man:': {'emoji': ' 👨\u200d❤️\u200d💋\u200d👨 ', 'tags': []},
              ':couplekiss_man_woman:': {'emoji': ' 💏 ', 'tags': []},
              ':couplekiss_woman_woman:': {'emoji': ' 👩\u200d❤️\u200d💋\u200d👩 ', 'tags': []},
              ':cow2:': {'emoji': ' 🐄 ', 'tags': []},
              ':cow:': {'emoji': ' 🐮 ', 'tags': []},
              ':cowboy_hat_face:': {'emoji': ' \U0001f920 ', 'tags': []},
              ':crab:': {'emoji': ' 🦀 ', 'tags': []},
              ':crayon:': {'emoji': ' 🖍 ', 'tags': []},
              ':credit_card:': {'emoji': ' 💳 ', 'tags': ['subscription']},
              ':crescent_moon:': {'emoji': ' 🌙 ', 'tags': ['night']},
              ':cricket:': {'emoji': ' 🏏 ', 'tags': []},
              ':croatia:': {'emoji': ' 🇭🇷 ', 'tags': []},
              ':crocodile:': {'emoji': ' 🐊 ', 'tags': []},
              ':croissant:': {'emoji': ' \U0001f950 ', 'tags': []},
              ':crossed_fingers:': {'emoji': ' \U0001f91e ', 'tags': ['luck', 'hopeful']},
              ':crossed_flags:': {'emoji': ' 🎌 ', 'tags': []},
              ':crossed_swords:': {'emoji': ' ⚔️ ', 'tags': []},
              ':crown:': {'emoji': ' 👑 ', 'tags': ['king', 'queen', 'royal']},
              ':cry:': {'emoji': ' 😢 ', 'tags': ['sad', 'tear']},
              ':crying_cat_face:': {'emoji': ' 😿 ', 'tags': ['sad', 'tear']},
              ':crystal_ball:': {'emoji': ' 🔮 ', 'tags': ['fortune']},
              ':cuba:': {'emoji': ' 🇨🇺 ', 'tags': []},
              ':cucumber:': {'emoji': ' \U0001f952 ', 'tags': []},
              ':cupid:': {'emoji': ' 💘 ', 'tags': ['love', 'heart']},
              ':curacao:': {'emoji': ' 🇨🇼 ', 'tags': []},
              ':curly_loop:': {'emoji': ' ➰ ', 'tags': []},
              ':currency_exchange:': {'emoji': ' 💱 ', 'tags': []},
              ':curry:': {'emoji': ' 🍛 ', 'tags': []},
              ':custard:': {'emoji': ' 🍮 ', 'tags': []},
              ':customs:': {'emoji': ' 🛃 ', 'tags': []},
              ':cyclone:': {'emoji': ' 🌀 ', 'tags': ['swirl']},
              ':cyprus:': {'emoji': ' 🇨🇾 ', 'tags': []},
              ':czech_republic:': {'emoji': ' 🇨🇿 ', 'tags': []},
              ':dagger:': {'emoji': ' 🗡 ', 'tags': []},
              ':dancer:': {'emoji': ' 💃 ', 'tags': ['dress']},
              ':dancers:': {'emoji': ' 👯 ', 'tags': ['bunny']},
              ':dancing_men:': {'emoji': ' 👯\u200d♂ ', 'tags': ['bunny']},
              ':dancing_women:': {'emoji': ' 👯 ', 'tags': ['bunny']},
              ':dango:': {'emoji': ' 🍡 ', 'tags': []},
              ':dark_sunglasses:': {'emoji': ' 🕶 ', 'tags': []},
              ':dart:': {'emoji': ' 🎯 ', 'tags': ['target']},
              ':dash:': {'emoji': ' 💨 ', 'tags': ['wind', 'blow', 'fast']},
              ':date:': {'emoji': ' 📅 ', 'tags': ['calendar', 'schedule']},
              ':de:': {'emoji': ' 🇩🇪 ', 'tags': ['flag', 'germany']},
              ':deciduous_tree:': {'emoji': ' 🌳 ', 'tags': ['wood']},
              ':deer:': {'emoji': ' \U0001f98c ', 'tags': []},
              ':denmark:': {'emoji': ' 🇩🇰 ', 'tags': []},
              ':department_store:': {'emoji': ' 🏬 ', 'tags': []},
              ':derelict_house:': {'emoji': ' 🏚 ', 'tags': []},
              ':desert:': {'emoji': ' 🏜 ', 'tags': []},
              ':desert_island:': {'emoji': ' 🏝 ', 'tags': []},
              ':desktop_computer:': {'emoji': ' 🖥 ', 'tags': []},
              ':detective:': {'emoji': ' 🕵 ', 'tags': ['sleuth']},
              ':diamond_shape_with_a_dot_inside:': {'emoji': ' 💠 ', 'tags': []},
              ':diamonds:': {'emoji': ' ♦️ ', 'tags': []},
              ':disappointed:': {'emoji': ' 😞 ', 'tags': ['sad']},
              ':disappointed_relieved:': {'emoji': ' 😥 ',
                                          'tags': ['phew', 'sweat', 'nervous']},
              ':dizzy:': {'emoji': ' 💫 ', 'tags': ['star']},
              ':dizzy_face:': {'emoji': ' 😵 ', 'tags': []},
              ':djibouti:': {'emoji': ' 🇩🇯 ', 'tags': []},
              ':do_not_litter:': {'emoji': ' 🚯 ', 'tags': []},
              ':dog2:': {'emoji': ' 🐕 ', 'tags': []},
              ':dog:': {'emoji': ' 🐶 ', 'tags': ['pet']},
              ':dollar:': {'emoji': ' 💵 ', 'tags': ['money']},
              ':dolls:': {'emoji': ' 🎎 ', 'tags': []},
              ':dolphin:': {'emoji': ' 🐬 ', 'tags': []},
              ':dominica:': {'emoji': ' 🇩🇲 ', 'tags': []},
              ':dominican_republic:': {'emoji': ' 🇩🇴 ', 'tags': []},
              ':door:': {'emoji': ' 🚪 ', 'tags': []},
              ':doughnut:': {'emoji': ' 🍩 ', 'tags': []},
              ':dove:': {'emoji': ' 🕊 ', 'tags': ['peace']},
              ':dragon:': {'emoji': ' 🐉 ', 'tags': []},
              ':dragon_face:': {'emoji': ' 🐲 ', 'tags': []},
              ':dress:': {'emoji': ' 👗 ', 'tags': []},
              ':dromedary_camel:': {'emoji': ' 🐪 ', 'tags': ['desert']},
              ':drooling_face:': {'emoji': ' \U0001f924 ', 'tags': []},
              ':droplet:': {'emoji': ' 💧 ', 'tags': ['water']},
              ':drum:': {'emoji': ' \U0001f941 ', 'tags': []},
              ':duck:': {'emoji': ' \U0001f986 ', 'tags': []},
              ':dvd:': {'emoji': ' 📀 ', 'tags': []},
              ':e-mail:': {'emoji': ' 📧 ', 'tags': []},
              ':eagle:': {'emoji': ' \U0001f985 ', 'tags': []},
              ':ear:': {'emoji': ' 👂 ', 'tags': ['hear', 'sound', 'listen']},
              ':ear_of_rice:': {'emoji': ' 🌾 ', 'tags': []},
              ':earth_africa:': {'emoji': ' 🌍 ',
                                 'tags': ['globe', 'world', 'international']},
              ':earth_americas:': {'emoji': ' 🌎 ',
                                   'tags': ['globe', 'world', 'international']},
              ':earth_asia:': {'emoji': ' 🌏 ', 'tags': ['globe', 'world', 'international']},
              ':ecuador:': {'emoji': ' 🇪🇨 ', 'tags': []},
              ':egg:': {'emoji': ' \U0001f95a ', 'tags': []},
              ':eggplant:': {'emoji': ' 🍆 ', 'tags': ['aubergine']},
              ':egypt:': {'emoji': ' 🇪🇬 ', 'tags': []},
              ':eight:': {'emoji': ' 8️⃣ ', 'tags': []},
              ':eight_pointed_black_star:': {'emoji': ' ✴️ ', 'tags': []},
              ':eight_spoked_asterisk:': {'emoji': ' ✳️ ', 'tags': []},
              ':el_salvador:': {'emoji': ' 🇸🇻 ', 'tags': []},
              ':electric_plug:': {'emoji': ' 🔌 ', 'tags': []},
              ':elephant:': {'emoji': ' 🐘 ', 'tags': []},
              ':email:': {'emoji': ' ✉️ ', 'tags': ['letter']},
              ':end:': {'emoji': ' 🔚 ', 'tags': []},
              ':envelope:': {'emoji': ' ✉️ ', 'tags': ['letter']},
              ':envelope_with_arrow:': {'emoji': ' 📩 ', 'tags': []},
              ':equatorial_guinea:': {'emoji': ' 🇬🇶 ', 'tags': []},
              ':eritrea:': {'emoji': ' 🇪🇷 ', 'tags': []},
              ':es:': {'emoji': ' 🇪🇸 ', 'tags': ['spain']},
              ':estonia:': {'emoji': ' 🇪🇪 ', 'tags': []},
              ':ethiopia:': {'emoji': ' 🇪🇹 ', 'tags': []},
              ':eu:': {'emoji': ' 🇪🇺 ', 'tags': []},
              ':euro:': {'emoji': ' 💶 ', 'tags': []},
              ':european_castle:': {'emoji': ' 🏰 ', 'tags': []},
              ':european_post_office:': {'emoji': ' 🏤 ', 'tags': []},
              ':european_union:': {'emoji': ' 🇪🇺 ', 'tags': []},
              ':evergreen_tree:': {'emoji': ' 🌲 ', 'tags': ['wood']},
              ':exclamation:': {'emoji': ' ❗️ ', 'tags': ['bang']},
              ':expressionless:': {'emoji': ' 😑 ', 'tags': []},
              ':eye:': {'emoji': ' 👁 ', 'tags': []},
              ':eye_speech_bubble:': {'emoji': ' 👁\u200d🗨 ', 'tags': []},
              ':eyeglasses:': {'emoji': ' 👓 ', 'tags': ['glasses']},
              ':eyes:': {'emoji': ' 👀 ', 'tags': ['look', 'see', 'watch']},
              ':face_with_head_bandage:': {'emoji': ' 🤕 ', 'tags': ['hurt']},
              ':face_with_thermometer:': {'emoji': ' 🤒 ', 'tags': ['sick']},
              ':facepunch:': {'emoji': ' 👊 ', 'tags': ['attack']},
              ':factory:': {'emoji': ' 🏭 ', 'tags': []},
              ':falkland_islands:': {'emoji': ' 🇫🇰 ', 'tags': []},
              ':fallen_leaf:': {'emoji': ' 🍂 ', 'tags': ['autumn']},
              ':family:': {'emoji': ' 👪 ', 'tags': ['home', 'parents', 'child']},
              ':family_man_boy:': {'emoji': ' 👨\u200d👦 ', 'tags': []},
              ':family_man_boy_boy:': {'emoji': ' 👨\u200d👦\u200d👦 ', 'tags': []},
              ':family_man_girl:': {'emoji': ' 👨\u200d👧 ', 'tags': []},
              ':family_man_girl_boy:': {'emoji': ' 👨\u200d👧\u200d👦 ', 'tags': []},
              ':family_man_girl_girl:': {'emoji': ' 👨\u200d👧\u200d👧 ', 'tags': []},
              ':family_man_man_boy:': {'emoji': ' 👨\u200d👨\u200d👦 ', 'tags': []},
              ':family_man_man_boy_boy:': {'emoji': ' 👨\u200d👨\u200d👦\u200d👦 ', 'tags': []},
              ':family_man_man_girl:': {'emoji': ' 👨\u200d👨\u200d👧 ', 'tags': []},
              ':family_man_man_girl_boy:': {'emoji': ' 👨\u200d👨\u200d👧\u200d👦 ', 'tags': []},
              ':family_man_man_girl_girl:': {'emoji': ' 👨\u200d👨\u200d👧\u200d👧 ',
                                             'tags': []},
              ':family_man_woman_boy:': {'emoji': ' 👪 ',
                                         'tags': ['home', 'parents', 'child']},
              ':family_man_woman_boy_boy:': {'emoji': ' 👨\u200d👩\u200d👦\u200d👦 ',
                                             'tags': []},
              ':family_man_woman_girl:': {'emoji': ' 👨\u200d👩\u200d👧 ', 'tags': []},
              ':family_man_woman_girl_boy:': {'emoji': ' 👨\u200d👩\u200d👧\u200d👦 ',
                                              'tags': []},
              ':family_man_woman_girl_girl:': {'emoji': ' 👨\u200d👩\u200d👧\u200d👧 ',
                                               'tags': []},
              ':family_woman_boy:': {'emoji': ' 👩\u200d👦 ', 'tags': []},
              ':family_woman_boy_boy:': {'emoji': ' 👩\u200d👦\u200d👦 ', 'tags': []},
              ':family_woman_girl:': {'emoji': ' 👩\u200d👧 ', 'tags': []},
              ':family_woman_girl_boy:': {'emoji': ' 👩\u200d👧\u200d👦 ', 'tags': []},
              ':family_woman_girl_girl:': {'emoji': ' 👩\u200d👧\u200d👧 ', 'tags': []},
              ':family_woman_woman_boy:': {'emoji': ' 👩\u200d👩\u200d👦 ', 'tags': []},
              ':family_woman_woman_boy_boy:': {'emoji': ' 👩\u200d👩\u200d👦\u200d👦 ',
                                               'tags': []},
              ':family_woman_woman_girl:': {'emoji': ' 👩\u200d👩\u200d👧 ', 'tags': []},
              ':family_woman_woman_girl_boy:': {'emoji': ' 👩\u200d👩\u200d👧\u200d👦 ',
                                                'tags': []},
              ':family_woman_woman_girl_girl:': {'emoji': ' 👩\u200d👩\u200d👧\u200d👧 ',
                                                 'tags': []},
              ':faroe_islands:': {'emoji': ' 🇫🇴 ', 'tags': []},
              ':fast_forward:': {'emoji': ' ⏩ ', 'tags': []},
              ':fax:': {'emoji': ' 📠 ', 'tags': []},
              ':fearful:': {'emoji': ' 😨 ', 'tags': ['scared', 'shocked', 'oops']},
              ':feet:': {'emoji': ' 🐾 ', 'tags': []},
              ':female_detective:': {'emoji': ' 🕵️\u200d♀️ ', 'tags': ['sleuth']},
              ':ferris_wheel:': {'emoji': ' 🎡 ', 'tags': []},
              ':ferry:': {'emoji': ' ⛴ ', 'tags': []},
              ':field_hockey:': {'emoji': ' 🏑 ', 'tags': []},
              ':fiji:': {'emoji': ' 🇫🇯 ', 'tags': []},
              ':file_cabinet:': {'emoji': ' 🗄 ', 'tags': []},
              ':file_folder:': {'emoji': ' 📁 ', 'tags': ['directory']},
              ':film_projector:': {'emoji': ' 📽 ', 'tags': []},
              ':film_strip:': {'emoji': ' 🎞 ', 'tags': []},
              ':finland:': {'emoji': ' 🇫🇮 ', 'tags': []},
              ':fire:': {'emoji': ' 🔥 ', 'tags': ['burn']},
              ':fire_engine:': {'emoji': ' 🚒 ', 'tags': []},
              ':fireworks:': {'emoji': ' 🎆 ', 'tags': ['festival', 'celebration']},
              ':first_quarter_moon:': {'emoji': ' 🌓 ', 'tags': []},
              ':first_quarter_moon_with_face:': {'emoji': ' 🌛 ', 'tags': []},
              ':fish:': {'emoji': ' 🐟 ', 'tags': []},
              ':fish_cake:': {'emoji': ' 🍥 ', 'tags': []},
              ':fishing_pole_and_fish:': {'emoji': ' 🎣 ', 'tags': []},
              ':fist:': {'emoji': ' ✊ ', 'tags': ['power']},
              ':fist_left:': {'emoji': ' \U0001f91b ', 'tags': []},
              ':fist_oncoming:': {'emoji': ' 👊 ', 'tags': ['attack']},
              ':fist_raised:': {'emoji': ' ✊ ', 'tags': ['power']},
              ':fist_right:': {'emoji': ' \U0001f91c ', 'tags': []},
              ':five:': {'emoji': ' 5️⃣ ', 'tags': []},
              ':flags:': {'emoji': ' 🎏 ', 'tags': []},
              ':flashlight:': {'emoji': ' 🔦 ', 'tags': []},
              ':fleur_de_lis:': {'emoji': ' ⚜️ ', 'tags': []},
              ':flight_arrival:': {'emoji': ' 🛬 ', 'tags': []},
              ':flight_departure:': {'emoji': ' 🛫 ', 'tags': []},
              ':flipper:': {'emoji': ' 🐬 ', 'tags': []},
              ':floppy_disk:': {'emoji': ' 💾 ', 'tags': ['save']},
              ':flower_playing_cards:': {'emoji': ' 🎴 ', 'tags': []},
              ':flushed:': {'emoji': ' 😳 ', 'tags': []},
              ':fog:': {'emoji': ' 🌫 ', 'tags': []},
              ':foggy:': {'emoji': ' 🌁 ', 'tags': ['karl']},
              ':football:': {'emoji': ' 🏈 ', 'tags': ['sports']},
              ':footprints:': {'emoji': ' 👣 ', 'tags': ['feet', 'tracks']},
              ':fork_and_knife:': {'emoji': ' 🍴 ', 'tags': ['cutlery']},
              ':fountain:': {'emoji': ' ⛲️ ', 'tags': []},
              ':fountain_pen:': {'emoji': ' 🖋 ', 'tags': []},
              ':four:': {'emoji': ' 4️⃣ ', 'tags': []},
              ':four_leaf_clover:': {'emoji': ' 🍀 ', 'tags': ['luck']},
              ':fox_face:': {'emoji': ' \U0001f98a ', 'tags': []},
              ':fr:': {'emoji': ' 🇫🇷 ', 'tags': ['france', 'french']},
              ':framed_picture:': {'emoji': ' 🖼 ', 'tags': []},
              ':free:': {'emoji': ' 🆓 ', 'tags': []},
              ':french_guiana:': {'emoji': ' 🇬🇫 ', 'tags': []},
              ':french_polynesia:': {'emoji': ' 🇵🇫 ', 'tags': []},
              ':french_southern_territories:': {'emoji': ' 🇹🇫 ', 'tags': []},
              ':fried_egg:': {'emoji': ' 🍳 ', 'tags': ['breakfast']},
              ':fried_shrimp:': {'emoji': ' 🍤 ', 'tags': ['tempura']},
              ':fries:': {'emoji': ' 🍟 ', 'tags': []},
              ':frog:': {'emoji': ' 🐸 ', 'tags': []},
              ':frowning:': {'emoji': ' 😦 ', 'tags': []},
              ':frowning_face:': {'emoji': ' ☹️ ', 'tags': []},
              ':frowning_man:': {'emoji': ' 🙍\u200d♂ ', 'tags': []},
              ':frowning_woman:': {'emoji': ' 🙍 ', 'tags': ['sad']},
              ':fu:': {'emoji': ' 🖕 ', 'tags': []},
              ':fuelpump:': {'emoji': ' ⛽️ ', 'tags': []},
              ':full_moon:': {'emoji': ' 🌕 ', 'tags': []},
              ':full_moon_with_face:': {'emoji': ' 🌝 ', 'tags': []},
              ':funeral_urn:': {'emoji': ' ⚱️ ', 'tags': []},
              ':gabon:': {'emoji': ' 🇬🇦 ', 'tags': []},
              ':gambia:': {'emoji': ' 🇬🇲 ', 'tags': []},
              ':game_die:': {'emoji': ' 🎲 ', 'tags': ['dice', 'gambling']},
              ':gb:': {'emoji': ' 🇬🇧 ', 'tags': ['flag', 'british']},
              ':gear:': {'emoji': ' ⚙️ ', 'tags': []},
              ':gem:': {'emoji': ' 💎 ', 'tags': ['diamond']},
              ':gemini:': {'emoji': ' ♊️ ', 'tags': []},
              ':georgia:': {'emoji': ' 🇬🇪 ', 'tags': []},
              ':ghana:': {'emoji': ' 🇬🇭 ', 'tags': []},
              ':ghost:': {'emoji': ' 👻 ', 'tags': ['halloween']},
              ':gibraltar:': {'emoji': ' 🇬🇮 ', 'tags': []},
              ':gift:': {'emoji': ' 🎁 ', 'tags': ['present', 'birthday', 'christmas']},
              ':gift_heart:': {'emoji': ' 💝 ', 'tags': ['chocolates']},
              ':girl:': {'emoji': ' 👧 ', 'tags': ['child']},
              ':globe_with_meridians:': {'emoji': ' 🌐 ',
                                         'tags': ['world', 'global', 'international']},
              ':goal_net:': {'emoji': ' \U0001f945 ', 'tags': []},
              ':goat:': {'emoji': ' 🐐 ', 'tags': []},
              ':golf:': {'emoji': ' ⛳️ ', 'tags': []},
              ':golfing_man:': {'emoji': ' 🏌 ', 'tags': []},
              ':golfing_woman:': {'emoji': ' 🏌️\u200d♀️ ', 'tags': []},
              ':gorilla:': {'emoji': ' \U0001f98d ', 'tags': []},
              ':grapes:': {'emoji': ' 🍇 ', 'tags': []},
              ':greece:': {'emoji': ' 🇬🇷 ', 'tags': []},
              ':green_apple:': {'emoji': ' 🍏 ', 'tags': ['fruit']},
              ':green_book:': {'emoji': ' 📗 ', 'tags': []},
              ':green_heart:': {'emoji': ' 💚 ', 'tags': []},
              ':green_salad:': {'emoji': ' \U0001f957 ', 'tags': []},
              ':greenland:': {'emoji': ' 🇬🇱 ', 'tags': []},
              ':grenada:': {'emoji': ' 🇬🇩 ', 'tags': []},
              ':grey_exclamation:': {'emoji': ' ❕ ', 'tags': []},
              ':grey_question:': {'emoji': ' ❔ ', 'tags': []},
              ':grimacing:': {'emoji': ' 😬 ', 'tags': []},
              ':grin:': {'emoji': ' 😁 ', 'tags': []},
              ':grinning:': {'emoji': ' 😀 ', 'tags': ['smile', 'happy']},
              ':guadeloupe:': {'emoji': ' 🇬🇵 ', 'tags': []},
              ':guam:': {'emoji': ' 🇬🇺 ', 'tags': []},
              ':guardsman:': {'emoji': ' 💂 ', 'tags': []},
              ':guardswoman:': {'emoji': ' 💂\u200d♀ ', 'tags': []},
              ':guatemala:': {'emoji': ' 🇬🇹 ', 'tags': []},
              ':guernsey:': {'emoji': ' 🇬🇬 ', 'tags': []},
              ':guinea:': {'emoji': ' 🇬🇳 ', 'tags': []},
              ':guinea_bissau:': {'emoji': ' 🇬🇼 ', 'tags': []},
              ':guitar:': {'emoji': ' 🎸 ', 'tags': ['rock']},
              ':gun:': {'emoji': ' 🔫 ', 'tags': ['shoot', 'weapon']},
              ':guyana:': {'emoji': ' 🇬🇾 ', 'tags': []},
              ':haircut:': {'emoji': ' 💇 ', 'tags': ['beauty']},
              ':haircut_man:': {'emoji': ' 💇\u200d♂ ', 'tags': []},
              ':haircut_woman:': {'emoji': ' 💇 ', 'tags': ['beauty']},
              ':haiti:': {'emoji': ' 🇭🇹 ', 'tags': []},
              ':hamburger:': {'emoji': ' 🍔 ', 'tags': ['burger']},
              ':hammer:': {'emoji': ' 🔨 ', 'tags': ['tool']},
              ':hammer_and_pick:': {'emoji': ' ⚒ ', 'tags': []},
              ':hammer_and_wrench:': {'emoji': ' 🛠 ', 'tags': []},
              ':hamster:': {'emoji': ' 🐹 ', 'tags': ['pet']},
              ':hand:': {'emoji': ' ✋ ', 'tags': ['highfive', 'stop']},
              ':handbag:': {'emoji': ' 👜 ', 'tags': ['bag']},
              ':handshake:': {'emoji': ' \U0001f91d ', 'tags': ['deal']},
              ':hankey:': {'emoji': ' 💩 ', 'tags': ['crap']},
              ':hash:': {'emoji': ' #️⃣ ', 'tags': ['number']},
              ':hatched_chick:': {'emoji': ' 🐥 ', 'tags': []},
              ':hatching_chick:': {'emoji': ' 🐣 ', 'tags': []},
              ':headphones:': {'emoji': ' 🎧 ', 'tags': ['music', 'earphones']},
              ':hear_no_evil:': {'emoji': ' 🙉 ', 'tags': ['monkey', 'deaf']},
              ':heart:': {'emoji': ' ❤️ ', 'tags': ['love']},
              ':heart_decoration:': {'emoji': ' 💟 ', 'tags': []},
              ':heart_eyes:': {'emoji': ' 😍 ', 'tags': ['love', 'crush']},
              ':heart_eyes_cat:': {'emoji': ' 😻 ', 'tags': []},
              ':heartbeat:': {'emoji': ' 💓 ', 'tags': []},
              ':heartpulse:': {'emoji': ' 💗 ', 'tags': []},
              ':hearts:': {'emoji': ' ♥️ ', 'tags': []},
              ':heavy_check_mark:': {'emoji': ' ✔️ ', 'tags': []},
              ':heavy_division_sign:': {'emoji': ' ➗ ', 'tags': []},
              ':heavy_dollar_sign:': {'emoji': ' 💲 ', 'tags': []},
              ':heavy_exclamation_mark:': {'emoji': ' ❗️ ', 'tags': ['bang']},
              ':heavy_heart_exclamation:': {'emoji': ' ❣️ ', 'tags': []},
              ':heavy_minus_sign:': {'emoji': ' ➖ ', 'tags': []},
              ':heavy_multiplication_x:': {'emoji': ' ✖️ ', 'tags': []},
              ':heavy_plus_sign:': {'emoji': ' ➕ ', 'tags': []},
              ':helicopter:': {'emoji': ' 🚁 ', 'tags': []},
              ':herb:': {'emoji': ' 🌿 ', 'tags': []},
              ':hibiscus:': {'emoji': ' 🌺 ', 'tags': []},
              ':high_brightness:': {'emoji': ' 🔆 ', 'tags': []},
              ':high_heel:': {'emoji': ' 👠 ', 'tags': ['shoe']},
              ':hocho:': {'emoji': ' 🔪 ', 'tags': ['cut', 'chop']},
              ':hole:': {'emoji': ' 🕳 ', 'tags': []},
              ':honduras:': {'emoji': ' 🇭🇳 ', 'tags': []},
              ':honey_pot:': {'emoji': ' 🍯 ', 'tags': []},
              ':honeybee:': {'emoji': ' 🐝 ', 'tags': []},
              ':hong_kong:': {'emoji': ' 🇭🇰 ', 'tags': []},
              ':horse:': {'emoji': ' 🐴 ', 'tags': []},
              ':horse_racing:': {'emoji': ' 🏇 ', 'tags': []},
              ':hospital:': {'emoji': ' 🏥 ', 'tags': []},
              ':hot_pepper:': {'emoji': ' 🌶 ', 'tags': ['spicy']},
              ':hotdog:': {'emoji': ' 🌭 ', 'tags': []},
              ':hotel:': {'emoji': ' 🏨 ', 'tags': []},
              ':hotsprings:': {'emoji': ' ♨️ ', 'tags': []},
              ':hourglass:': {'emoji': ' ⌛️ ', 'tags': ['time']},
              ':hourglass_flowing_sand:': {'emoji': ' ⏳ ', 'tags': ['time']},
              ':house:': {'emoji': ' 🏠 ', 'tags': []},
              ':house_with_garden:': {'emoji': ' 🏡 ', 'tags': []},
              ':houses:': {'emoji': ' 🏘 ', 'tags': []},
              ':hugs:': {'emoji': ' 🤗 ', 'tags': []},
              ':hungary:': {'emoji': ' 🇭🇺 ', 'tags': []},
              ':hushed:': {'emoji': ' 😯 ', 'tags': ['silence', 'speechless']},
              ':ice_cream:': {'emoji': ' 🍨 ', 'tags': []},
              ':ice_hockey:': {'emoji': ' 🏒 ', 'tags': []},
              ':ice_skate:': {'emoji': ' ⛸ ', 'tags': ['skating']},
              ':icecream:': {'emoji': ' 🍦 ', 'tags': []},
              ':iceland:': {'emoji': ' 🇮🇸 ', 'tags': []},
              ':id:': {'emoji': ' 🆔 ', 'tags': []},
              ':ideograph_advantage:': {'emoji': ' 🉐 ', 'tags': []},
              ':imp:': {'emoji': ' 👿 ', 'tags': ['angry', 'devil', 'evil', 'horns']},
              ':inbox_tray:': {'emoji': ' 📥 ', 'tags': []},
              ':incoming_envelope:': {'emoji': ' 📨 ', 'tags': []},
              ':india:': {'emoji': ' 🇮🇳 ', 'tags': []},
              ':indonesia:': {'emoji': ' 🇮🇩 ', 'tags': []},
              ':information_desk_person:': {'emoji': ' 💁 ', 'tags': []},
              ':information_source:': {'emoji': ' ℹ️ ', 'tags': []},
              ':innocent:': {'emoji': ' 😇 ', 'tags': ['angel']},
              ':interrobang:': {'emoji': ' ⁉️ ', 'tags': []},
              ':iphone:': {'emoji': ' 📱 ', 'tags': ['smartphone', 'mobile']},
              ':iran:': {'emoji': ' 🇮🇷 ', 'tags': []},
              ':iraq:': {'emoji': ' 🇮🇶 ', 'tags': []},
              ':ireland:': {'emoji': ' 🇮🇪 ', 'tags': []},
              ':isle_of_man:': {'emoji': ' 🇮🇲 ', 'tags': []},
              ':israel:': {'emoji': ' 🇮🇱 ', 'tags': []},
              ':it:': {'emoji': ' 🇮🇹 ', 'tags': ['italy']},
              ':izakaya_lantern:': {'emoji': ' 🏮 ', 'tags': []},
              ':jack_o_lantern:': {'emoji': ' 🎃 ', 'tags': ['halloween']},
              ':jamaica:': {'emoji': ' 🇯🇲 ', 'tags': []},
              ':japan:': {'emoji': ' 🗾 ', 'tags': []},
              ':japanese_castle:': {'emoji': ' 🏯 ', 'tags': []},
              ':japanese_goblin:': {'emoji': ' 👺 ', 'tags': []},
              ':japanese_ogre:': {'emoji': ' 👹 ', 'tags': ['monster']},
              ':jeans:': {'emoji': ' 👖 ', 'tags': ['pants']},
              ':jersey:': {'emoji': ' 🇯🇪 ', 'tags': []},
              ':jordan:': {'emoji': ' 🇯🇴 ', 'tags': []},
              ':joy:': {'emoji': ' 😂 ', 'tags': ['tears']},
              ':joy_cat:': {'emoji': ' 😹 ', 'tags': []},
              ':joystick:': {'emoji': ' 🕹 ', 'tags': []},
              ':jp:': {'emoji': ' 🇯🇵 ', 'tags': ['japan']},
              ':kaaba:': {'emoji': ' 🕋 ', 'tags': []},
              ':kazakhstan:': {'emoji': ' 🇰🇿 ', 'tags': []},
              ':kenya:': {'emoji': ' 🇰🇪 ', 'tags': []},
              ':key:': {'emoji': ' 🔑 ', 'tags': ['lock', 'password']},
              ':keyboard:': {'emoji': ' ⌨️ ', 'tags': []},
              ':keycap_ten:': {'emoji': ' 🔟 ', 'tags': []},
              ':kick_scooter:': {'emoji': ' \U0001f6f4 ', 'tags': []},
              ':kimono:': {'emoji': ' 👘 ', 'tags': []},
              ':kiribati:': {'emoji': ' 🇰🇮 ', 'tags': []},
              ':kiss:': {'emoji': ' 💋 ', 'tags': ['lipstick']},
              ':kissing:': {'emoji': ' 😗 ', 'tags': []},
              ':kissing_cat:': {'emoji': ' 😽 ', 'tags': []},
              ':kissing_closed_eyes:': {'emoji': ' 😚 ', 'tags': []},
              ':kissing_heart:': {'emoji': ' 😘 ', 'tags': ['flirt']},
              ':kissing_smiling_eyes:': {'emoji': ' 😙 ', 'tags': []},
              ':kiwi_fruit:': {'emoji': ' \U0001f95d ', 'tags': []},
              ':knife:': {'emoji': ' 🔪 ', 'tags': ['cut', 'chop']},
              ':koala:': {'emoji': ' 🐨 ', 'tags': []},
              ':koko:': {'emoji': ' 🈁 ', 'tags': []},
              ':kosovo:': {'emoji': ' 🇽🇰 ', 'tags': []},
              ':kr:': {'emoji': ' 🇰🇷 ', 'tags': ['korea']},
              ':kuwait:': {'emoji': ' 🇰🇼 ', 'tags': []},
              ':kyrgyzstan:': {'emoji': ' 🇰🇬 ', 'tags': []},
              ':label:': {'emoji': ' 🏷 ', 'tags': ['tag']},
              ':lantern:': {'emoji': ' 🏮 ', 'tags': []},
              ':laos:': {'emoji': ' 🇱🇦 ', 'tags': []},
              ':large_blue_circle:': {'emoji': ' 🔵 ', 'tags': []},
              ':large_blue_diamond:': {'emoji': ' 🔷 ', 'tags': []},
              ':large_orange_diamond:': {'emoji': ' 🔶 ', 'tags': []},
              ':last_quarter_moon:': {'emoji': ' 🌗 ', 'tags': []},
              ':last_quarter_moon_with_face:': {'emoji': ' 🌜 ', 'tags': []},
              ':latin_cross:': {'emoji': ' ✝️ ', 'tags': []},
              ':latvia:': {'emoji': ' 🇱🇻 ', 'tags': []},
              ':laughing:': {'emoji': ' 😆 ', 'tags': ['happy', 'haha']},
              ':leaves:': {'emoji': ' 🍃 ', 'tags': ['leaf']},
              ':lebanon:': {'emoji': ' 🇱🇧 ', 'tags': []},
              ':ledger:': {'emoji': ' 📒 ', 'tags': []},
              ':left_luggage:': {'emoji': ' 🛅 ', 'tags': []},
              ':left_right_arrow:': {'emoji': ' ↔️ ', 'tags': []},
              ':leftwards_arrow_with_hook:': {'emoji': ' ↩️ ', 'tags': ['return']},
              ':lemon:': {'emoji': ' 🍋 ', 'tags': []},
              ':leo:': {'emoji': ' ♌️ ', 'tags': []},
              ':leopard:': {'emoji': ' 🐆 ', 'tags': []},
              ':lesotho:': {'emoji': ' 🇱🇸 ', 'tags': []},
              ':level_slider:': {'emoji': ' 🎚 ', 'tags': []},
              ':liberia:': {'emoji': ' 🇱🇷 ', 'tags': []},
              ':libra:': {'emoji': ' ♎️ ', 'tags': []},
              ':libya:': {'emoji': ' 🇱🇾 ', 'tags': []},
              ':liechtenstein:': {'emoji': ' 🇱🇮 ', 'tags': []},
              ':light_rail:': {'emoji': ' 🚈 ', 'tags': []},
              ':link:': {'emoji': ' 🔗 ', 'tags': []},
              ':lion:': {'emoji': ' 🦁 ', 'tags': []},
              ':lips:': {'emoji': ' 👄 ', 'tags': ['kiss']},
              ':lipstick:': {'emoji': ' 💄 ', 'tags': ['makeup']},
              ':lithuania:': {'emoji': ' 🇱🇹 ', 'tags': []},
              ':lizard:': {'emoji': ' \U0001f98e ', 'tags': []},
              ':lock:': {'emoji': ' 🔒 ', 'tags': ['security', 'private']},
              ':lock_with_ink_pen:': {'emoji': ' 🔏 ', 'tags': []},
              ':lollipop:': {'emoji': ' 🍭 ', 'tags': []},
              ':loop:': {'emoji': ' ➿ ', 'tags': []},
              ':loud_sound:': {'emoji': ' 🔊 ', 'tags': ['volume']},
              ':loudspeaker:': {'emoji': ' 📢 ', 'tags': ['announcement']},
              ':love_hotel:': {'emoji': ' 🏩 ', 'tags': []},
              ':love_letter:': {'emoji': ' 💌 ', 'tags': ['email', 'envelope']},
              ':low_brightness:': {'emoji': ' 🔅 ', 'tags': []},
              ':luxembourg:': {'emoji': ' 🇱🇺 ', 'tags': []},
              ':lying_face:': {'emoji': ' \U0001f925 ', 'tags': ['liar']},
              ':m:': {'emoji': ' Ⓜ️ ', 'tags': []},
              ':macau:': {'emoji': ' 🇲🇴 ', 'tags': []},
              ':macedonia:': {'emoji': ' 🇲🇰 ', 'tags': []},
              ':madagascar:': {'emoji': ' 🇲🇬 ', 'tags': []},
              ':mag:': {'emoji': ' 🔍 ', 'tags': ['search', 'zoom']},
              ':mag_right:': {'emoji': ' 🔎 ', 'tags': []},
              ':mahjong:': {'emoji': ' 🀄️ ', 'tags': []},
              ':mailbox:': {'emoji': ' 📫 ', 'tags': []},
              ':mailbox_closed:': {'emoji': ' 📪 ', 'tags': []},
              ':mailbox_with_mail:': {'emoji': ' 📬 ', 'tags': []},
              ':mailbox_with_no_mail:': {'emoji': ' 📭 ', 'tags': []},
              ':malawi:': {'emoji': ' 🇲🇼 ', 'tags': []},
              ':malaysia:': {'emoji': ' 🇲🇾 ', 'tags': []},
              ':maldives:': {'emoji': ' 🇲🇻 ', 'tags': []},
              ':male_detective:': {'emoji': ' 🕵 ', 'tags': ['sleuth']},
              ':mali:': {'emoji': ' 🇲🇱 ', 'tags': []},
              ':malta:': {'emoji': ' 🇲🇹 ', 'tags': []},
              ':man:': {'emoji': ' 👨 ', 'tags': ['mustache', 'father', 'dad']},
              ':man_artist:': {'emoji': ' 👨\u200d🎨 ', 'tags': ['painter']},
              ':man_astronaut:': {'emoji': ' 👨\u200d🚀 ', 'tags': ['space']},
              ':man_cartwheeling:': {'emoji': ' \U0001f938\u200d♂ ', 'tags': []},
              ':man_cook:': {'emoji': ' 👨\u200d🍳 ', 'tags': ['chef']},
              ':man_dancing:': {'emoji': ' \U0001f57a ', 'tags': ['dancer']},
              ':man_facepalming:': {'emoji': ' \U0001f926\u200d♂ ', 'tags': []},
              ':man_factory_worker:': {'emoji': ' 👨\u200d🏭 ', 'tags': []},
              ':man_farmer:': {'emoji': ' 👨\u200d🌾 ', 'tags': []},
              ':man_firefighter:': {'emoji': ' 👨\u200d🚒 ', 'tags': []},
              ':man_health_worker:': {'emoji': ' 👨\u200d⚕ ', 'tags': ['doctor', 'nurse']},
              ':man_in_tuxedo:': {'emoji': ' \U0001f935 ',
                                  'tags': ['groom', 'marriage', 'wedding']},
              ':man_judge:': {'emoji': ' 👨\u200d⚖ ', 'tags': ['justice']},
              ':man_juggling:': {'emoji': ' \U0001f939\u200d♂ ', 'tags': []},
              ':man_mechanic:': {'emoji': ' 👨\u200d🔧 ', 'tags': []},
              ':man_office_worker:': {'emoji': ' 👨\u200d💼 ', 'tags': ['business']},
              ':man_pilot:': {'emoji': ' 👨\u200d✈ ', 'tags': []},
              ':man_playing_handball:': {'emoji': ' \U0001f93e\u200d♂ ', 'tags': []},
              ':man_playing_water_polo:': {'emoji': ' \U0001f93d\u200d♂ ', 'tags': []},
              ':man_scientist:': {'emoji': ' 👨\u200d🔬 ', 'tags': ['research']},
              ':man_shrugging:': {'emoji': ' \U0001f937\u200d♂ ', 'tags': []},
              ':man_singer:': {'emoji': ' 👨\u200d🎤 ', 'tags': ['rockstar']},
              ':man_student:': {'emoji': ' 👨\u200d🎓 ', 'tags': ['graduation']},
              ':man_teacher:': {'emoji': ' 👨\u200d🏫 ', 'tags': ['school', 'professor']},
              ':man_technologist:': {'emoji': ' 👨\u200d💻 ', 'tags': ['coder']},
              ':man_with_gua_pi_mao:': {'emoji': ' 👲 ', 'tags': []},
              ':man_with_turban:': {'emoji': ' 👳 ', 'tags': []},
              ':mandarin:': {'emoji': ' 🍊 ', 'tags': []},
              ':mans_shoe:': {'emoji': ' 👞 ', 'tags': []},
              ':mantelpiece_clock:': {'emoji': ' 🕰 ', 'tags': []},
              ':maple_leaf:': {'emoji': ' 🍁 ', 'tags': ['canada']},
              ':marshall_islands:': {'emoji': ' 🇲🇭 ', 'tags': []},
              ':martial_arts_uniform:': {'emoji': ' \U0001f94b ', 'tags': []},
              ':martinique:': {'emoji': ' 🇲🇶 ', 'tags': []},
              ':mask:': {'emoji': ' 😷 ', 'tags': ['sick', 'ill']},
              ':massage:': {'emoji': ' 💆 ', 'tags': ['spa']},
              ':massage_man:': {'emoji': ' 💆\u200d♂ ', 'tags': ['spa']},
              ':massage_woman:': {'emoji': ' 💆 ', 'tags': ['spa']},
              ':mauritania:': {'emoji': ' 🇲🇷 ', 'tags': []},
              ':mauritius:': {'emoji': ' 🇲🇺 ', 'tags': []},
              ':mayotte:': {'emoji': ' 🇾🇹 ', 'tags': []},
              ':meat_on_bone:': {'emoji': ' 🍖 ', 'tags': []},
              ':medal_military:': {'emoji': ' 🎖 ', 'tags': []},
              ':medal_sports:': {'emoji': ' 🏅 ', 'tags': ['gold', 'winner']},
              ':mega:': {'emoji': ' 📣 ', 'tags': []},
              ':melon:': {'emoji': ' 🍈 ', 'tags': []},
              ':memo:': {'emoji': ' 📝 ', 'tags': ['document', 'note']},
              ':men_wrestling:': {'emoji': ' \U0001f93c\u200d♂ ', 'tags': []},
              ':menorah:': {'emoji': ' 🕎 ', 'tags': []},
              ':mens:': {'emoji': ' 🚹 ', 'tags': []},
              ':metal:': {'emoji': ' 🤘 ', 'tags': []},
              ':metro:': {'emoji': ' 🚇 ', 'tags': []},
              ':mexico:': {'emoji': ' 🇲🇽 ', 'tags': []},
              ':micronesia:': {'emoji': ' 🇫🇲 ', 'tags': []},
              ':microphone:': {'emoji': ' 🎤 ', 'tags': ['sing']},
              ':microscope:': {'emoji': ' 🔬 ',
                               'tags': ['science', 'laboratory', 'investigate']},
              ':middle_finger:': {'emoji': ' 🖕 ', 'tags': []},
              ':milk_glass:': {'emoji': ' \U0001f95b ', 'tags': []},
              ':milky_way:': {'emoji': ' 🌌 ', 'tags': []},
              ':minibus:': {'emoji': ' 🚐 ', 'tags': []},
              ':minidisc:': {'emoji': ' 💽 ', 'tags': []},
              ':mobile_phone_off:': {'emoji': ' 📴 ', 'tags': ['mute', 'off']},
              ':moldova:': {'emoji': ' 🇲🇩 ', 'tags': []},
              ':monaco:': {'emoji': ' 🇲🇨 ', 'tags': []},
              ':money_mouth_face:': {'emoji': ' 🤑 ', 'tags': ['rich']},
              ':money_with_wings:': {'emoji': ' 💸 ', 'tags': ['dollar']},
              ':moneybag:': {'emoji': ' 💰 ', 'tags': ['dollar', 'cream']},
              ':mongolia:': {'emoji': ' 🇲🇳 ', 'tags': []},
              ':monkey:': {'emoji': ' 🐒 ', 'tags': []},
              ':monkey_face:': {'emoji': ' 🐵 ', 'tags': []},
              ':monorail:': {'emoji': ' 🚝 ', 'tags': []},
              ':montenegro:': {'emoji': ' 🇲🇪 ', 'tags': []},
              ':montserrat:': {'emoji': ' 🇲🇸 ', 'tags': []},
              ':moon:': {'emoji': ' 🌔 ', 'tags': []},
              ':morocco:': {'emoji': ' 🇲🇦 ', 'tags': []},
              ':mortar_board:': {'emoji': ' 🎓 ',
                                 'tags': ['education',
                                          'college',
                                          'university',
                                          'graduation']},
              ':mosque:': {'emoji': ' 🕌 ', 'tags': []},
              ':motor_boat:': {'emoji': ' 🛥 ', 'tags': []},
              ':motor_scooter:': {'emoji': ' \U0001f6f5 ', 'tags': []},
              ':motorcycle:': {'emoji': ' 🏍 ', 'tags': []},
              ':motorway:': {'emoji': ' 🛣 ', 'tags': []},
              ':mount_fuji:': {'emoji': ' 🗻 ', 'tags': []},
              ':mountain:': {'emoji': ' ⛰ ', 'tags': []},
              ':mountain_bicyclist:': {'emoji': ' 🚵 ', 'tags': []},
              ':mountain_biking_man:': {'emoji': ' 🚵 ', 'tags': []},
              ':mountain_biking_woman:': {'emoji': ' 🚵\u200d♀ ', 'tags': []},
              ':mountain_cableway:': {'emoji': ' 🚠 ', 'tags': []},
              ':mountain_railway:': {'emoji': ' 🚞 ', 'tags': []},
              ':mountain_snow:': {'emoji': ' 🏔 ', 'tags': []},
              ':mouse2:': {'emoji': ' 🐁 ', 'tags': []},
              ':mouse:': {'emoji': ' 🐭 ', 'tags': []},
              ':movie_camera:': {'emoji': ' 🎥 ', 'tags': ['film', 'video']},
              ':moyai:': {'emoji': ' 🗿 ', 'tags': ['stone']},
              ':mozambique:': {'emoji': ' 🇲🇿 ', 'tags': []},
              ':mrs_claus:': {'emoji': ' \U0001f936 ', 'tags': ['santa']},
              ':muscle:': {'emoji': ' 💪 ', 'tags': ['flex', 'bicep', 'strong', 'workout']},
              ':mushroom:': {'emoji': ' 🍄 ', 'tags': []},
              ':musical_keyboard:': {'emoji': ' 🎹 ', 'tags': ['piano']},
              ':musical_note:': {'emoji': ' 🎵 ', 'tags': []},
              ':musical_score:': {'emoji': ' 🎼 ', 'tags': []},
              ':mute:': {'emoji': ' 🔇 ', 'tags': ['sound', 'volume']},
              ':myanmar:': {'emoji': ' 🇲🇲 ', 'tags': ['burma']},
              ':nail_care:': {'emoji': ' 💅 ', 'tags': ['beauty', 'manicure']},
              ':name_badge:': {'emoji': ' 📛 ', 'tags': []},
              ':namibia:': {'emoji': ' 🇳🇦 ', 'tags': []},
              ':national_park:': {'emoji': ' 🏞 ', 'tags': []},
              ':nauru:': {'emoji': ' 🇳🇷 ', 'tags': []},
              ':nauseated_face:': {'emoji': ' \U0001f922 ',
                                   'tags': ['sick', 'barf', 'disgusted']},
              ':necktie:': {'emoji': ' 👔 ', 'tags': ['shirt', 'formal']},
              ':negative_squared_cross_mark:': {'emoji': ' ❎ ', 'tags': []},
              ':nepal:': {'emoji': ' 🇳🇵 ', 'tags': []},
              ':nerd_face:': {'emoji': ' 🤓 ', 'tags': ['geek', 'glasses']},
              ':netherlands:': {'emoji': ' 🇳🇱 ', 'tags': []},
              ':neutral_face:': {'emoji': ' 😐 ', 'tags': ['meh']},
              ':new:': {'emoji': ' 🆕 ', 'tags': ['fresh']},
              ':new_caledonia:': {'emoji': ' 🇳🇨 ', 'tags': []},
              ':new_moon:': {'emoji': ' 🌑 ', 'tags': []},
              ':new_moon_with_face:': {'emoji': ' 🌚 ', 'tags': []},
              ':new_zealand:': {'emoji': ' 🇳🇿 ', 'tags': []},
              ':newspaper:': {'emoji': ' 📰 ', 'tags': ['press']},
              ':newspaper_roll:': {'emoji': ' 🗞 ', 'tags': ['press']},
              ':next_track_button:': {'emoji': ' ⏭ ', 'tags': []},
              ':ng:': {'emoji': ' 🆖 ', 'tags': []},
              ':ng_man:': {'emoji': ' 🙅\u200d♂ ', 'tags': ['stop', 'halt']},
              ':ng_woman:': {'emoji': ' 🙅 ', 'tags': ['stop', 'halt']},
              ':nicaragua:': {'emoji': ' 🇳🇮 ', 'tags': []},
              ':niger:': {'emoji': ' 🇳🇪 ', 'tags': []},
              ':nigeria:': {'emoji': ' 🇳🇬 ', 'tags': []},
              ':night_with_stars:': {'emoji': ' 🌃 ', 'tags': []},
              ':nine:': {'emoji': ' 9️⃣ ', 'tags': []},
              ':niue:': {'emoji': ' 🇳🇺 ', 'tags': []},
              ':no_bell:': {'emoji': ' 🔕 ', 'tags': ['volume', 'off']},
              ':no_bicycles:': {'emoji': ' 🚳 ', 'tags': []},
              ':no_entry:': {'emoji': ' ⛔️ ', 'tags': ['limit']},
              ':no_entry_sign:': {'emoji': ' 🚫 ', 'tags': ['block', 'forbidden']},
              ':no_good:': {'emoji': ' 🙅 ', 'tags': ['stop', 'halt']},
              ':no_good_man:': {'emoji': ' 🙅\u200d♂ ', 'tags': ['stop', 'halt']},
              ':no_good_woman:': {'emoji': ' 🙅 ', 'tags': ['stop', 'halt']},
              ':no_mobile_phones:': {'emoji': ' 📵 ', 'tags': []},
              ':no_mouth:': {'emoji': ' 😶 ', 'tags': ['mute', 'silence']},
              ':no_pedestrians:': {'emoji': ' 🚷 ', 'tags': []},
              ':no_smoking:': {'emoji': ' 🚭 ', 'tags': []},
              ':non-potable_water:': {'emoji': ' 🚱 ', 'tags': []},
              ':norfolk_island:': {'emoji': ' 🇳🇫 ', 'tags': []},
              ':north_korea:': {'emoji': ' 🇰🇵 ', 'tags': []},
              ':northern_mariana_islands:': {'emoji': ' 🇲🇵 ', 'tags': []},
              ':norway:': {'emoji': ' 🇳🇴 ', 'tags': []},
              ':nose:': {'emoji': ' 👃 ', 'tags': ['smell']},
              ':notebook:': {'emoji': ' 📓 ', 'tags': []},
              ':notebook_with_decorative_cover:': {'emoji': ' 📔 ', 'tags': []},
              ':notes:': {'emoji': ' 🎶 ', 'tags': ['music']},
              ':nut_and_bolt:': {'emoji': ' 🔩 ', 'tags': []},
              ':o2:': {'emoji': ' 🅾️ ', 'tags': []},
              ':o:': {'emoji': ' ⭕️ ', 'tags': []},
              ':ocean:': {'emoji': ' 🌊 ', 'tags': ['sea']},
              ':octopus:': {'emoji': ' 🐙 ', 'tags': []},
              ':oden:': {'emoji': ' 🍢 ', 'tags': []},
              ':office:': {'emoji': ' 🏢 ', 'tags': []},
              ':oil_drum:': {'emoji': ' 🛢 ', 'tags': []},
              ':ok:': {'emoji': ' 🆗 ', 'tags': ['yes']},
              ':ok_hand:': {'emoji': ' 👌 ', 'tags': []},
              ':ok_man:': {'emoji': ' 🙆\u200d♂ ', 'tags': []},
              ':ok_woman:': {'emoji': ' 🙆 ', 'tags': []},
              ':old_key:': {'emoji': ' 🗝 ', 'tags': []},
              ':older_man:': {'emoji': ' 👴 ', 'tags': []},
              ':older_woman:': {'emoji': ' 👵 ', 'tags': []},
              ':om:': {'emoji': ' 🕉 ', 'tags': []},
              ':oman:': {'emoji': ' 🇴🇲 ', 'tags': []},
              ':on:': {'emoji': ' 🔛 ', 'tags': []},
              ':oncoming_automobile:': {'emoji': ' 🚘 ', 'tags': []},
              ':oncoming_bus:': {'emoji': ' 🚍 ', 'tags': []},
              ':oncoming_police_car:': {'emoji': ' 🚔 ', 'tags': []},
              ':oncoming_taxi:': {'emoji': ' 🚖 ', 'tags': []},
              ':one:': {'emoji': ' 1️⃣ ', 'tags': []},
              ':open_book:': {'emoji': ' 📖 ', 'tags': []},
              ':open_file_folder:': {'emoji': ' 📂 ', 'tags': []},
              ':open_hands:': {'emoji': ' 👐 ', 'tags': []},
              ':open_mouth:': {'emoji': ' 😮 ', 'tags': ['surprise', 'impressed', 'wow']},
              ':open_umbrella:': {'emoji': ' ☂️ ', 'tags': []},
              ':ophiuchus:': {'emoji': ' ⛎ ', 'tags': []},
              ':orange:': {'emoji': ' 🍊 ', 'tags': []},
              ':orange_book:': {'emoji': ' 📙 ', 'tags': []},
              ':orthodox_cross:': {'emoji': ' ☦️ ', 'tags': []},
              ':outbox_tray:': {'emoji': ' 📤 ', 'tags': []},
              ':owl:': {'emoji': ' \U0001f989 ', 'tags': []},
              ':ox:': {'emoji': ' 🐂 ', 'tags': []},
              ':package:': {'emoji': ' 📦 ', 'tags': ['shipping']},
              ':page_facing_up:': {'emoji': ' 📄 ', 'tags': ['document']},
              ':page_with_curl:': {'emoji': ' 📃 ', 'tags': []},
              ':pager:': {'emoji': ' 📟 ', 'tags': []},
              ':paintbrush:': {'emoji': ' 🖌 ', 'tags': []},
              ':pakistan:': {'emoji': ' 🇵🇰 ', 'tags': []},
              ':palau:': {'emoji': ' 🇵🇼 ', 'tags': []},
              ':palestinian_territories:': {'emoji': ' 🇵🇸 ', 'tags': []},
              ':palm_tree:': {'emoji': ' 🌴 ', 'tags': []},
              ':panama:': {'emoji': ' 🇵🇦 ', 'tags': []},
              ':pancakes:': {'emoji': ' \U0001f95e ', 'tags': []},
              ':panda_face:': {'emoji': ' 🐼 ', 'tags': []},
              ':paperclip:': {'emoji': ' 📎 ', 'tags': []},
              ':paperclips:': {'emoji': ' 🖇 ', 'tags': []},
              ':papua_new_guinea:': {'emoji': ' 🇵🇬 ', 'tags': []},
              ':paraguay:': {'emoji': ' 🇵🇾 ', 'tags': []},
              ':parasol_on_ground:': {'emoji': ' ⛱ ', 'tags': ['beach_umbrella']},
              ':parking:': {'emoji': ' 🅿️ ', 'tags': []},
              ':part_alternation_mark:': {'emoji': ' 〽️ ', 'tags': []},
              ':partly_sunny:': {'emoji': ' ⛅️ ', 'tags': ['weather', 'cloud']},
              ':passenger_ship:': {'emoji': ' 🛳 ', 'tags': ['cruise']},
              ':passport_control:': {'emoji': ' 🛂 ', 'tags': []},
              ':pause_button:': {'emoji': ' ⏸ ', 'tags': []},
              ':paw_prints:': {'emoji': ' 🐾 ', 'tags': []},
              ':peace_symbol:': {'emoji': ' ☮️ ', 'tags': []},
              ':peach:': {'emoji': ' 🍑 ', 'tags': []},
              ':peanuts:': {'emoji': ' \U0001f95c ', 'tags': []},
              ':pear:': {'emoji': ' 🍐 ', 'tags': []},
              ':pen:': {'emoji': ' 🖊 ', 'tags': []},
              ':pencil2:': {'emoji': ' ✏️ ', 'tags': []},
              ':pencil:': {'emoji': ' 📝 ', 'tags': ['document', 'note']},
              ':penguin:': {'emoji': ' 🐧 ', 'tags': []},
              ':pensive:': {'emoji': ' 😔 ', 'tags': []},
              ':performing_arts:': {'emoji': ' 🎭 ', 'tags': ['theater', 'drama']},
              ':persevere:': {'emoji': ' 😣 ', 'tags': ['struggling']},
              ':person_fencing:': {'emoji': ' \U0001f93a ', 'tags': []},
              ':person_frowning:': {'emoji': ' 🙍 ', 'tags': ['sad']},
              ':person_with_blond_hair:': {'emoji': ' 👱 ', 'tags': ['boy']},
              ':person_with_pouting_face:': {'emoji': ' 🙎 ', 'tags': []},
              ':peru:': {'emoji': ' 🇵🇪 ', 'tags': []},
              ':philippines:': {'emoji': ' 🇵🇭 ', 'tags': []},
              ':phone:': {'emoji': ' ☎️ ', 'tags': []},
              ':pick:': {'emoji': ' ⛏ ', 'tags': []},
              ':pig2:': {'emoji': ' 🐖 ', 'tags': []},
              ':pig:': {'emoji': ' 🐷 ', 'tags': []},
              ':pig_nose:': {'emoji': ' 🐽 ', 'tags': []},
              ':pill:': {'emoji': ' 💊 ', 'tags': ['health', 'medicine']},
              ':pineapple:': {'emoji': ' 🍍 ', 'tags': []},
              ':ping_pong:': {'emoji': ' 🏓 ', 'tags': []},
              ':pisces:': {'emoji': ' ♓️ ', 'tags': []},
              ':pitcairn_islands:': {'emoji': ' 🇵🇳 ', 'tags': []},
              ':pizza:': {'emoji': ' 🍕 ', 'tags': []},
              ':place_of_worship:': {'emoji': ' 🛐 ', 'tags': []},
              ':plate_with_cutlery:': {'emoji': ' 🍽 ', 'tags': ['dining', 'dinner']},
              ':play_or_pause_button:': {'emoji': ' ⏯ ', 'tags': []},
              ':point_down:': {'emoji': ' 👇 ', 'tags': []},
              ':point_left:': {'emoji': ' 👈 ', 'tags': []},
              ':point_right:': {'emoji': ' 👉 ', 'tags': []},
              ':point_up:': {'emoji': ' ☝️ ', 'tags': []},
              ':point_up_2:': {'emoji': ' 👆 ', 'tags': []},
              ':poland:': {'emoji': ' 🇵🇱 ', 'tags': []},
              ':police_car:': {'emoji': ' 🚓 ', 'tags': []},
              ':policeman:': {'emoji': ' 👮 ', 'tags': ['police', 'law']},
              ':policewoman:': {'emoji': ' 👮\u200d♀ ', 'tags': []},
              ':poodle:': {'emoji': ' 🐩 ', 'tags': ['dog']},
              ':poop:': {'emoji': ' 💩 ', 'tags': ['crap']},
              ':popcorn:': {'emoji': ' 🍿 ', 'tags': []},
              ':portugal:': {'emoji': ' 🇵🇹 ', 'tags': []},
              ':post_office:': {'emoji': ' 🏣 ', 'tags': []},
              ':postal_horn:': {'emoji': ' 📯 ', 'tags': []},
              ':postbox:': {'emoji': ' 📮 ', 'tags': []},
              ':potable_water:': {'emoji': ' 🚰 ', 'tags': []},
              ':potato:': {'emoji': ' \U0001f954 ', 'tags': []},
              ':pouch:': {'emoji': ' 👝 ', 'tags': ['bag']},
              ':poultry_leg:': {'emoji': ' 🍗 ', 'tags': ['meat', 'chicken']},
              ':pound:': {'emoji': ' 💷 ', 'tags': []},
              ':pout:': {'emoji': ' 😡 ', 'tags': ['angry']},
              ':pouting_cat:': {'emoji': ' 😾 ', 'tags': []},
              ':pouting_man:': {'emoji': ' 🙎\u200d♂ ', 'tags': []},
              ':pouting_woman:': {'emoji': ' 🙎 ', 'tags': []},
              ':pray:': {'emoji': ' 🙏 ', 'tags': ['please', 'hope', 'wish']},
              ':prayer_beads:': {'emoji': ' 📿 ', 'tags': []},
              ':pregnant_woman:': {'emoji': ' \U0001f930 ', 'tags': []},
              ':previous_track_button:': {'emoji': ' ⏮ ', 'tags': []},
              ':prince:': {'emoji': ' \U0001f934 ', 'tags': ['crown', 'royal']},
              ':princess:': {'emoji': ' 👸 ', 'tags': ['blonde', 'crown', 'royal']},
              ':printer:': {'emoji': ' 🖨 ', 'tags': []},
              ':puerto_rico:': {'emoji': ' 🇵🇷 ', 'tags': []},
              ':punch:': {'emoji': ' 👊 ', 'tags': ['attack']},
              ':purple_heart:': {'emoji': ' 💜 ', 'tags': []},
              ':purse:': {'emoji': ' 👛 ', 'tags': []},
              ':pushpin:': {'emoji': ' 📌 ', 'tags': ['location']},
              ':put_litter_in_its_place:': {'emoji': ' 🚮 ', 'tags': []},
              ':qatar:': {'emoji': ' 🇶🇦 ', 'tags': []},
              ':question:': {'emoji': ' ❓ ', 'tags': ['confused']},
              ':rabbit2:': {'emoji': ' 🐇 ', 'tags': []},
              ':rabbit:': {'emoji': ' 🐰 ', 'tags': ['bunny']},
              ':racehorse:': {'emoji': ' 🐎 ', 'tags': ['speed']},
              ':racing_car:': {'emoji': ' 🏎 ', 'tags': []},
              ':radio:': {'emoji': ' 📻 ', 'tags': ['podcast']},
              ':radio_button:': {'emoji': ' 🔘 ', 'tags': []},
              ':radioactive:': {'emoji': ' ☢️ ', 'tags': []},
              ':rage:': {'emoji': ' 😡 ', 'tags': ['angry']},
              ':railway_car:': {'emoji': ' 🚃 ', 'tags': []},
              ':railway_track:': {'emoji': ' 🛤 ', 'tags': []},
              ':rainbow:': {'emoji': ' 🌈 ', 'tags': []},
              ':rainbow_flag:': {'emoji': ' 🏳️\u200d🌈 ', 'tags': ['pride']},
              ':raised_back_of_hand:': {'emoji': ' \U0001f91a ', 'tags': []},
              ':raised_hand:': {'emoji': ' ✋ ', 'tags': ['highfive', 'stop']},
              ':raised_hand_with_fingers_splayed:': {'emoji': ' 🖐 ', 'tags': []},
              ':raised_hands:': {'emoji': ' 🙌 ', 'tags': ['hooray']},
              ':raising_hand:': {'emoji': ' 🙋 ', 'tags': []},
              ':raising_hand_man:': {'emoji': ' 🙋\u200d♂ ', 'tags': []},
              ':raising_hand_woman:': {'emoji': ' 🙋 ', 'tags': []},
              ':ram:': {'emoji': ' 🐏 ', 'tags': []},
              ':ramen:': {'emoji': ' 🍜 ', 'tags': ['noodle']},
              ':rat:': {'emoji': ' 🐀 ', 'tags': []},
              ':record_button:': {'emoji': ' ⏺ ', 'tags': []},
              ':recycle:': {'emoji': ' ♻️ ', 'tags': ['environment', 'green']},
              ':red_car:': {'emoji': ' 🚗 ', 'tags': []},
              ':red_circle:': {'emoji': ' 🔴 ', 'tags': []},
              ':registered:': {'emoji': ' ®️ ', 'tags': []},
              ':relaxed:': {'emoji': ' ☺️ ', 'tags': ['blush', 'pleased']},
              ':relieved:': {'emoji': ' 😌 ', 'tags': ['whew']},
              ':reminder_ribbon:': {'emoji': ' 🎗 ', 'tags': []},
              ':repeat:': {'emoji': ' 🔁 ', 'tags': ['loop']},
              ':repeat_one:': {'emoji': ' 🔂 ', 'tags': []},
              ':rescue_worker_helmet:': {'emoji': ' ⛑ ', 'tags': []},
              ':restroom:': {'emoji': ' 🚻 ', 'tags': ['toilet']},
              ':reunion:': {'emoji': ' 🇷🇪 ', 'tags': []},
              ':revolving_hearts:': {'emoji': ' 💞 ', 'tags': []},
              ':rewind:': {'emoji': ' ⏪ ', 'tags': []},
              ':rhinoceros:': {'emoji': ' \U0001f98f ', 'tags': []},
              ':ribbon:': {'emoji': ' 🎀 ', 'tags': []},
              ':rice:': {'emoji': ' 🍚 ', 'tags': []},
              ':rice_ball:': {'emoji': ' 🍙 ', 'tags': []},
              ':rice_cracker:': {'emoji': ' 🍘 ', 'tags': []},
              ':rice_scene:': {'emoji': ' 🎑 ', 'tags': []},
              ':right_anger_bubble:': {'emoji': ' 🗯 ', 'tags': []},
              ':ring:': {'emoji': ' 💍 ', 'tags': ['wedding', 'marriage', 'engaged']},
              ':robot:': {'emoji': ' 🤖 ', 'tags': []},
              ':rocket:': {'emoji': ' 🚀 ', 'tags': ['ship', 'launch']},
              ':rofl:': {'emoji': ' \U0001f923 ', 'tags': ['lol', 'laughing']},
              ':roll_eyes:': {'emoji': ' 🙄 ', 'tags': []},
              ':roller_coaster:': {'emoji': ' 🎢 ', 'tags': []},
              ':romania:': {'emoji': ' 🇷🇴 ', 'tags': []},
              ':rooster:': {'emoji': ' 🐓 ', 'tags': []},
              ':rose:': {'emoji': ' 🌹 ', 'tags': ['flower']},
              ':rosette:': {'emoji': ' 🏵 ', 'tags': []},
              ':rotating_light:': {'emoji': ' 🚨 ', 'tags': ['911', 'emergency']},
              ':round_pushpin:': {'emoji': ' 📍 ', 'tags': ['location']},
              ':rowboat:': {'emoji': ' 🚣 ', 'tags': []},
              ':rowing_man:': {'emoji': ' 🚣 ', 'tags': []},
              ':rowing_woman:': {'emoji': ' 🚣\u200d♀ ', 'tags': []},
              ':ru:': {'emoji': ' 🇷🇺 ', 'tags': ['russia']},
              ':rugby_football:': {'emoji': ' 🏉 ', 'tags': []},
              ':runner:': {'emoji': ' 🏃 ', 'tags': ['exercise', 'workout', 'marathon']},
              ':running:': {'emoji': ' 🏃 ', 'tags': ['exercise', 'workout', 'marathon']},
              ':running_man:': {'emoji': ' 🏃 ', 'tags': ['exercise', 'workout', 'marathon']},
              ':running_shirt_with_sash:': {'emoji': ' 🎽 ', 'tags': ['marathon']},
              ':running_woman:': {'emoji': ' 🏃\u200d♀ ',
                                  'tags': ['exercise', 'workout', 'marathon']},
              ':rwanda:': {'emoji': ' 🇷🇼 ', 'tags': []},
              ':sa:': {'emoji': ' 🈂️ ', 'tags': []},
              ':sagittarius:': {'emoji': ' ♐️ ', 'tags': []},
              ':sailboat:': {'emoji': ' ⛵️ ', 'tags': []},
              ':sake:': {'emoji': ' 🍶 ', 'tags': []},
              ':samoa:': {'emoji': ' 🇼🇸 ', 'tags': []},
              ':san_marino:': {'emoji': ' 🇸🇲 ', 'tags': []},
              ':sandal:': {'emoji': ' 👡 ', 'tags': ['shoe']},
              ':santa:': {'emoji': ' 🎅 ', 'tags': ['christmas']},
              ':sao_tome_principe:': {'emoji': ' 🇸🇹 ', 'tags': []},
              ':sassy_man:': {'emoji': ' 💁\u200d♂ ', 'tags': ['information']},
              ':sassy_woman:': {'emoji': ' 💁 ', 'tags': []},
              ':satellite:': {'emoji': ' 📡 ', 'tags': ['signal']},
              ':satisfied:': {'emoji': ' 😆 ', 'tags': ['happy', 'haha']},
              ':saudi_arabia:': {'emoji': ' 🇸🇦 ', 'tags': []},
              ':saxophone:': {'emoji': ' 🎷 ', 'tags': []},
              ':school:': {'emoji': ' 🏫 ', 'tags': []},
              ':school_satchel:': {'emoji': ' 🎒 ', 'tags': []},
              ':scissors:': {'emoji': ' ✂️ ', 'tags': ['cut']},
              ':scorpion:': {'emoji': ' 🦂 ', 'tags': []},
              ':scorpius:': {'emoji': ' ♏️ ', 'tags': []},
              ':scream:': {'emoji': ' 😱 ', 'tags': ['horror', 'shocked']},
              ':scream_cat:': {'emoji': ' 🙀 ', 'tags': ['horror']},
              ':scroll:': {'emoji': ' 📜 ', 'tags': ['document']},
              ':seat:': {'emoji': ' 💺 ', 'tags': []},
              ':secret:': {'emoji': ' ㊙️ ', 'tags': []},
              ':see_no_evil:': {'emoji': ' 🙈 ', 'tags': ['monkey', 'blind', 'ignore']},
              ':seedling:': {'emoji': ' 🌱 ', 'tags': ['plant']},
              ':selfie:': {'emoji': ' \U0001f933 ', 'tags': []},
              ':senegal:': {'emoji': ' 🇸🇳 ', 'tags': []},
              ':serbia:': {'emoji': ' 🇷🇸 ', 'tags': []},
              ':seven:': {'emoji': ' 7️⃣ ', 'tags': []},
              ':seychelles:': {'emoji': ' 🇸🇨 ', 'tags': []},
              ':shallow_pan_of_food:': {'emoji': ' \U0001f958 ',
                                        'tags': ['paella', 'curry']},
              ':shamrock:': {'emoji': ' ☘️ ', 'tags': []},
              ':shark:': {'emoji': ' \U0001f988 ', 'tags': []},
              ':shaved_ice:': {'emoji': ' 🍧 ', 'tags': []},
              ':sheep:': {'emoji': ' 🐑 ', 'tags': []},
              ':shell:': {'emoji': ' 🐚 ', 'tags': ['sea', 'beach']},
              ':shield:': {'emoji': ' 🛡 ', 'tags': []},
              ':shinto_shrine:': {'emoji': ' ⛩ ', 'tags': []},
              ':ship:': {'emoji': ' 🚢 ', 'tags': []},
              ':shirt:': {'emoji': ' 👕 ', 'tags': []},
              ':shit:': {'emoji': ' 💩 ', 'tags': ['crap']},
              ':shoe:': {'emoji': ' 👞 ', 'tags': []},
              ':shopping:': {'emoji': ' 🛍 ', 'tags': ['bags']},
              ':shopping_cart:': {'emoji': ' \U0001f6d2 ', 'tags': []},
              ':shower:': {'emoji': ' 🚿 ', 'tags': ['bath']},
              ':shrimp:': {'emoji': ' \U0001f990 ', 'tags': []},
              ':sierra_leone:': {'emoji': ' 🇸🇱 ', 'tags': []},
              ':signal_strength:': {'emoji': ' 📶 ', 'tags': ['wifi']},
              ':singapore:': {'emoji': ' 🇸🇬 ', 'tags': []},
              ':sint_maarten:': {'emoji': ' 🇸🇽 ', 'tags': []},
              ':six:': {'emoji': ' 6️⃣ ', 'tags': []},
              ':six_pointed_star:': {'emoji': ' 🔯 ', 'tags': []},
              ':ski:': {'emoji': ' 🎿 ', 'tags': []},
              ':skier:': {'emoji': ' ⛷ ', 'tags': []},
              ':skull:': {'emoji': ' 💀 ', 'tags': ['dead', 'danger', 'poison']},
              ':skull_and_crossbones:': {'emoji': ' ☠️ ', 'tags': ['danger', 'pirate']},
              ':sleeping:': {'emoji': ' 😴 ', 'tags': ['zzz']},
              ':sleeping_bed:': {'emoji': ' 🛌 ', 'tags': []},
              ':sleepy:': {'emoji': ' 😪 ', 'tags': ['tired']},
              ':slightly_frowning_face:': {'emoji': ' 🙁 ', 'tags': []},
              ':slightly_smiling_face:': {'emoji': ' 🙂 ', 'tags': []},
              ':slot_machine:': {'emoji': ' 🎰 ', 'tags': []},
              ':slovakia:': {'emoji': ' 🇸🇰 ', 'tags': []},
              ':slovenia:': {'emoji': ' 🇸🇮 ', 'tags': []},
              ':small_airplane:': {'emoji': ' 🛩 ', 'tags': ['flight']},
              ':small_blue_diamond:': {'emoji': ' 🔹 ', 'tags': []},
              ':small_orange_diamond:': {'emoji': ' 🔸 ', 'tags': []},
              ':small_red_triangle:': {'emoji': ' 🔺 ', 'tags': []},
              ':small_red_triangle_down:': {'emoji': ' 🔻 ', 'tags': []},
              ':smile:': {'emoji': ' 😄 ', 'tags': ['happy', 'joy', 'laugh', 'pleased']},
              ':smile_cat:': {'emoji': ' 😸 ', 'tags': []},
              ':smiley:': {'emoji': ' 😃 ', 'tags': ['happy', 'joy', 'haha']},
              ':smiley_cat:': {'emoji': ' 😺 ', 'tags': []},
              ':smiling_imp:': {'emoji': ' 😈 ', 'tags': ['devil', 'evil', 'horns']},
              ':smirk:': {'emoji': ' 😏 ', 'tags': ['smug']},
              ':smirk_cat:': {'emoji': ' 😼 ', 'tags': []},
              ':smoking:': {'emoji': ' 🚬 ', 'tags': ['cigarette']},
              ':snail:': {'emoji': ' 🐌 ', 'tags': ['slow']},
              ':snake:': {'emoji': ' 🐍 ', 'tags': []},
              ':sneezing_face:': {'emoji': ' \U0001f927 ', 'tags': ['achoo', 'sick']},
              ':snowboarder:': {'emoji': ' 🏂 ', 'tags': []},
              ':snowflake:': {'emoji': ' ❄️ ', 'tags': ['winter', 'cold', 'weather']},
              ':snowman:': {'emoji': ' ⛄️ ', 'tags': ['winter']},
              ':snowman_with_snow:': {'emoji': ' ☃️ ', 'tags': ['winter', 'christmas']},
              ':sob:': {'emoji': ' 😭 ', 'tags': ['sad', 'cry', 'bawling']},
              ':soccer:': {'emoji': ' ⚽️ ', 'tags': ['sports']},
              ':solomon_islands:': {'emoji': ' 🇸🇧 ', 'tags': []},
              ':somalia:': {'emoji': ' 🇸🇴 ', 'tags': []},
              ':soon:': {'emoji': ' 🔜 ', 'tags': []},
              ':sos:': {'emoji': ' 🆘 ', 'tags': ['help', 'emergency']},
              ':sound:': {'emoji': ' 🔉 ', 'tags': ['volume']},
              ':south_africa:': {'emoji': ' 🇿🇦 ', 'tags': []},
              ':south_georgia_south_sandwich_islands:': {'emoji': ' 🇬🇸 ', 'tags': []},
              ':south_sudan:': {'emoji': ' 🇸🇸 ', 'tags': []},
              ':space_invader:': {'emoji': ' 👾 ', 'tags': ['game', 'retro']},
              ':spades:': {'emoji': ' ♠️ ', 'tags': []},
              ':spaghetti:': {'emoji': ' 🍝 ', 'tags': ['pasta']},
              ':sparkle:': {'emoji': ' ❇️ ', 'tags': []},
              ':sparkler:': {'emoji': ' 🎇 ', 'tags': []},
              ':sparkles:': {'emoji': ' ✨ ', 'tags': ['shiny']},
              ':sparkling_heart:': {'emoji': ' 💖 ', 'tags': []},
              ':speak_no_evil:': {'emoji': ' 🙊 ', 'tags': ['monkey', 'mute', 'hush']},
              ':speaker:': {'emoji': ' 🔈 ', 'tags': []},
              ':speaking_head:': {'emoji': ' 🗣 ', 'tags': []},
              ':speech_balloon:': {'emoji': ' 💬 ', 'tags': ['comment']},
              ':speedboat:': {'emoji': ' 🚤 ', 'tags': ['ship']},
              ':spider:': {'emoji': ' 🕷 ', 'tags': []},
              ':spider_web:': {'emoji': ' 🕸 ', 'tags': []},
              ':spiral_calendar:': {'emoji': ' 🗓 ', 'tags': []},
              ':spiral_notepad:': {'emoji': ' 🗒 ', 'tags': []},
              ':spoon:': {'emoji': ' \U0001f944 ', 'tags': []},
              ':squid:': {'emoji': ' \U0001f991 ', 'tags': []},
              ':sri_lanka:': {'emoji': ' 🇱🇰 ', 'tags': []},
              ':st_barthelemy:': {'emoji': ' 🇧🇱 ', 'tags': []},
              ':st_helena:': {'emoji': ' 🇸🇭 ', 'tags': []},
              ':st_kitts_nevis:': {'emoji': ' 🇰🇳 ', 'tags': []},
              ':st_lucia:': {'emoji': ' 🇱🇨 ', 'tags': []},
              ':st_pierre_miquelon:': {'emoji': ' 🇵🇲 ', 'tags': []},
              ':st_vincent_grenadines:': {'emoji': ' 🇻🇨 ', 'tags': []},
              ':stadium:': {'emoji': ' 🏟 ', 'tags': []},
              ':star2:': {'emoji': ' 🌟 ', 'tags': []},
              ':star:': {'emoji': ' ⭐️ ', 'tags': []},
              ':star_and_crescent:': {'emoji': ' ☪️ ', 'tags': []},
              ':star_of_david:': {'emoji': ' ✡️ ', 'tags': []},
              ':stars:': {'emoji': ' 🌠 ', 'tags': []},
              ':station:': {'emoji': ' 🚉 ', 'tags': []},
              ':statue_of_liberty:': {'emoji': ' 🗽 ', 'tags': []},
              ':steam_locomotive:': {'emoji': ' 🚂 ', 'tags': ['train']},
              ':stew:': {'emoji': ' 🍲 ', 'tags': []},
              ':stop_button:': {'emoji': ' ⏹ ', 'tags': []},
              ':stop_sign:': {'emoji': ' \U0001f6d1 ', 'tags': []},
              ':stopwatch:': {'emoji': ' ⏱ ', 'tags': []},
              ':straight_ruler:': {'emoji': ' 📏 ', 'tags': []},
              ':strawberry:': {'emoji': ' 🍓 ', 'tags': ['fruit']},
              ':stuck_out_tongue:': {'emoji': ' 😛 ', 'tags': []},
              ':stuck_out_tongue_closed_eyes:': {'emoji': ' 😝 ', 'tags': ['prank']},
              ':stuck_out_tongue_winking_eye:': {'emoji': ' 😜 ', 'tags': ['prank', 'silly']},
              ':studio_microphone:': {'emoji': ' 🎙 ', 'tags': ['podcast']},
              ':stuffed_flatbread:': {'emoji': ' \U0001f959 ', 'tags': []},
              ':sudan:': {'emoji': ' 🇸🇩 ', 'tags': []},
              ':sun_behind_large_cloud:': {'emoji': ' 🌥 ', 'tags': []},
              ':sun_behind_rain_cloud:': {'emoji': ' 🌦 ', 'tags': []},
              ':sun_behind_small_cloud:': {'emoji': ' 🌤 ', 'tags': []},
              ':sun_with_face:': {'emoji': ' 🌞 ', 'tags': ['summer']},
              ':sunflower:': {'emoji': ' 🌻 ', 'tags': []},
              ':sunglasses:': {'emoji': ' 😎 ', 'tags': ['cool']},
              ':sunny:': {'emoji': ' ☀️ ', 'tags': ['weather']},
              ':sunrise:': {'emoji': ' 🌅 ', 'tags': []},
              ':sunrise_over_mountains:': {'emoji': ' 🌄 ', 'tags': []},
              ':surfer:': {'emoji': ' 🏄 ', 'tags': []},
              ':surfing_man:': {'emoji': ' 🏄 ', 'tags': []},
              ':surfing_woman:': {'emoji': ' 🏄\u200d♀ ', 'tags': []},
              ':suriname:': {'emoji': ' 🇸🇷 ', 'tags': []},
              ':sushi:': {'emoji': ' 🍣 ', 'tags': []},
              ':suspension_railway:': {'emoji': ' 🚟 ', 'tags': []},
              ':swaziland:': {'emoji': ' 🇸🇿 ', 'tags': []},
              ':sweat:': {'emoji': ' 😓 ', 'tags': []},
              ':sweat_drops:': {'emoji': ' 💦 ', 'tags': ['water', 'workout']},
              ':sweat_smile:': {'emoji': ' 😅 ', 'tags': ['hot']},
              ':sweden:': {'emoji': ' 🇸🇪 ', 'tags': []},
              ':sweet_potato:': {'emoji': ' 🍠 ', 'tags': []},
              ':swimmer:': {'emoji': ' 🏊 ', 'tags': []},
              ':swimming_man:': {'emoji': ' 🏊 ', 'tags': []},
              ':swimming_woman:': {'emoji': ' 🏊\u200d♀ ', 'tags': []},
              ':switzerland:': {'emoji': ' 🇨🇭 ', 'tags': []},
              ':symbols:': {'emoji': ' 🔣 ', 'tags': []},
              ':synagogue:': {'emoji': ' 🕍 ', 'tags': []},
              ':syria:': {'emoji': ' 🇸🇾 ', 'tags': []},
              ':syringe:': {'emoji': ' 💉 ', 'tags': ['health', 'hospital', 'needle']},
              ':taco:': {'emoji': ' 🌮 ', 'tags': []},
              ':tada:': {'emoji': ' 🎉 ', 'tags': ['hooray', 'party']},
              ':taiwan:': {'emoji': ' 🇹🇼 ', 'tags': []},
              ':tajikistan:': {'emoji': ' 🇹🇯 ', 'tags': []},
              ':tanabata_tree:': {'emoji': ' 🎋 ', 'tags': []},
              ':tangerine:': {'emoji': ' 🍊 ', 'tags': []},
              ':tanzania:': {'emoji': ' 🇹🇿 ', 'tags': []},
              ':taurus:': {'emoji': ' ♉️ ', 'tags': []},
              ':taxi:': {'emoji': ' 🚕 ', 'tags': []},
              ':tea:': {'emoji': ' 🍵 ', 'tags': ['green', 'breakfast']},
              ':telephone:': {'emoji': ' ☎️ ', 'tags': []},
              ':telephone_receiver:': {'emoji': ' 📞 ', 'tags': ['phone', 'call']},
              ':telescope:': {'emoji': ' 🔭 ', 'tags': []},
              ':tennis:': {'emoji': ' 🎾 ', 'tags': ['sports']},
              ':tent:': {'emoji': ' ⛺️ ', 'tags': ['camping']},
              ':thailand:': {'emoji': ' 🇹🇭 ', 'tags': []},
              ':thermometer:': {'emoji': ' 🌡 ', 'tags': []},
              ':thinking:': {'emoji': ' 🤔 ', 'tags': []},
              ':thought_balloon:': {'emoji': ' 💭 ', 'tags': ['thinking']},
              ':three:': {'emoji': ' 3️⃣ ', 'tags': []},
              ':thumbsdown:': {'emoji': ' 👎 ', 'tags': ['disapprove', 'bury']},
              ':thumbsup:': {'emoji': ' 👍 ', 'tags': ['approve', 'ok']},
              ':ticket:': {'emoji': ' 🎫 ', 'tags': []},
              ':tickets:': {'emoji': ' 🎟 ', 'tags': []},
              ':tiger2:': {'emoji': ' 🐅 ', 'tags': []},
              ':tiger:': {'emoji': ' 🐯 ', 'tags': []},
              ':timer_clock:': {'emoji': ' ⏲ ', 'tags': []},
              ':timor_leste:': {'emoji': ' 🇹🇱 ', 'tags': []},
              ':tipping_hand_man:': {'emoji': ' 💁\u200d♂ ', 'tags': ['information']},
              ':tipping_hand_woman:': {'emoji': ' 💁 ', 'tags': []},
              ':tired_face:': {'emoji': ' 😫 ', 'tags': ['upset', 'whine']},
              ':tm:': {'emoji': ' ™️ ', 'tags': ['trademark']},
              ':togo:': {'emoji': ' 🇹🇬 ', 'tags': []},
              ':toilet:': {'emoji': ' 🚽 ', 'tags': ['wc']},
              ':tokelau:': {'emoji': ' 🇹🇰 ', 'tags': []},
              ':tokyo_tower:': {'emoji': ' 🗼 ', 'tags': []},
              ':tomato:': {'emoji': ' 🍅 ', 'tags': []},
              ':tonga:': {'emoji': ' 🇹🇴 ', 'tags': []},
              ':tongue:': {'emoji': ' 👅 ', 'tags': ['taste']},
              ':top:': {'emoji': ' 🔝 ', 'tags': []},
              ':tophat:': {'emoji': ' 🎩 ', 'tags': ['hat', 'classy']},
              ':tornado:': {'emoji': ' 🌪 ', 'tags': []},
              ':tr:': {'emoji': ' 🇹🇷 ', 'tags': ['turkey']},
              ':trackball:': {'emoji': ' 🖲 ', 'tags': []},
              ':tractor:': {'emoji': ' 🚜 ', 'tags': []},
              ':traffic_light:': {'emoji': ' 🚥 ', 'tags': []},
              ':train2:': {'emoji': ' 🚆 ', 'tags': []},
              ':train:': {'emoji': ' 🚋 ', 'tags': []},
              ':tram:': {'emoji': ' 🚊 ', 'tags': []},
              ':triangular_flag_on_post:': {'emoji': ' 🚩 ', 'tags': []},
              ':triangular_ruler:': {'emoji': ' 📐 ', 'tags': []},
              ':trident:': {'emoji': ' 🔱 ', 'tags': []},
              ':trinidad_tobago:': {'emoji': ' 🇹🇹 ', 'tags': []},
              ':triumph:': {'emoji': ' 😤 ', 'tags': ['smug']},
              ':trolleybus:': {'emoji': ' 🚎 ', 'tags': []},
              ':trophy:': {'emoji': ' 🏆 ', 'tags': ['award', 'contest', 'winner']},
              ':tropical_drink:': {'emoji': ' 🍹 ', 'tags': ['summer', 'vacation']},
              ':tropical_fish:': {'emoji': ' 🐠 ', 'tags': []},
              ':truck:': {'emoji': ' 🚚 ', 'tags': []},
              ':trumpet:': {'emoji': ' 🎺 ', 'tags': []},
              ':tshirt:': {'emoji': ' 👕 ', 'tags': []},
              ':tulip:': {'emoji': ' 🌷 ', 'tags': ['flower']},
              ':tumbler_glass:': {'emoji': ' \U0001f943 ', 'tags': ['whisky']},
              ':tunisia:': {'emoji': ' 🇹🇳 ', 'tags': []},
              ':turkey:': {'emoji': ' 🦃 ', 'tags': ['thanksgiving']},
              ':turkmenistan:': {'emoji': ' 🇹🇲 ', 'tags': []},
              ':turks_caicos_islands:': {'emoji': ' 🇹🇨 ', 'tags': []},
              ':turtle:': {'emoji': ' 🐢 ', 'tags': ['slow']},
              ':tuvalu:': {'emoji': ' 🇹🇻 ', 'tags': []},
              ':tv:': {'emoji': ' 📺 ', 'tags': []},
              ':twisted_rightwards_arrows:': {'emoji': ' 🔀 ', 'tags': ['shuffle']},
              ':two:': {'emoji': ' 2️⃣ ', 'tags': []},
              ':two_hearts:': {'emoji': ' 💕 ', 'tags': []},
              ':two_men_holding_hands:': {'emoji': ' 👬 ', 'tags': ['couple', 'date']},
              ':two_women_holding_hands:': {'emoji': ' 👭 ', 'tags': ['couple', 'date']},
              ':u5272:': {'emoji': ' 🈹 ', 'tags': []},
              ':u5408:': {'emoji': ' 🈴 ', 'tags': []},
              ':u55b6:': {'emoji': ' 🈺 ', 'tags': []},
              ':u6307:': {'emoji': ' 🈯️ ', 'tags': []},
              ':u6708:': {'emoji': ' 🈷️ ', 'tags': []},
              ':u6709:': {'emoji': ' 🈶 ', 'tags': []},
              ':u6e80:': {'emoji': ' 🈵 ', 'tags': []},
              ':u7121:': {'emoji': ' 🈚️ ', 'tags': []},
              ':u7533:': {'emoji': ' 🈸 ', 'tags': []},
              ':u7981:': {'emoji': ' 🈲 ', 'tags': []},
              ':u7a7a:': {'emoji': ' 🈳 ', 'tags': []},
              ':uganda:': {'emoji': ' 🇺🇬 ', 'tags': []},
              ':uk:': {'emoji': ' 🇬🇧 ', 'tags': ['flag', 'british']},
              ':ukraine:': {'emoji': ' 🇺🇦 ', 'tags': []},
              ':umbrella:': {'emoji': ' ☔️ ', 'tags': ['rain', 'weather']},
              ':unamused:': {'emoji': ' 😒 ', 'tags': ['meh']},
              ':underage:': {'emoji': ' 🔞 ', 'tags': []},
              ':unicorn:': {'emoji': ' 🦄 ', 'tags': []},
              ':united_arab_emirates:': {'emoji': ' 🇦🇪 ', 'tags': []},
              ':unlock:': {'emoji': ' 🔓 ', 'tags': ['security']},
              ':up:': {'emoji': ' 🆙 ', 'tags': []},
              ':upside_down_face:': {'emoji': ' 🙃 ', 'tags': []},
              ':uruguay:': {'emoji': ' 🇺🇾 ', 'tags': []},
              ':us:': {'emoji': ' 🇺🇸 ', 'tags': ['flag', 'united', 'america']},
              ':us_virgin_islands:': {'emoji': ' 🇻🇮 ', 'tags': []},
              ':uzbekistan:': {'emoji': ' 🇺🇿 ', 'tags': []},
              ':v:': {'emoji': ' ✌️ ', 'tags': ['victory', 'peace']},
              ':vanuatu:': {'emoji': ' 🇻🇺 ', 'tags': []},
              ':vatican_city:': {'emoji': ' 🇻🇦 ', 'tags': []},
              ':venezuela:': {'emoji': ' 🇻🇪 ', 'tags': []},
              ':vertical_traffic_light:': {'emoji': ' 🚦 ', 'tags': ['semaphore']},
              ':vhs:': {'emoji': ' 📼 ', 'tags': []},
              ':vibration_mode:': {'emoji': ' 📳 ', 'tags': []},
              ':video_camera:': {'emoji': ' 📹 ', 'tags': []},
              ':video_game:': {'emoji': ' 🎮 ', 'tags': ['play', 'controller', 'console']},
              ':vietnam:': {'emoji': ' 🇻🇳 ', 'tags': []},
              ':violin:': {'emoji': ' 🎻 ', 'tags': []},
              ':virgo:': {'emoji': ' ♍️ ', 'tags': []},
              ':volcano:': {'emoji': ' 🌋 ', 'tags': []},
              ':volleyball:': {'emoji': ' 🏐 ', 'tags': []},
              ':vs:': {'emoji': ' 🆚 ', 'tags': []},
              ':vulcan_salute:': {'emoji': ' 🖖 ', 'tags': ['prosper', 'spock']},
              ':walking:': {'emoji': ' 🚶 ', 'tags': []},
              ':walking_man:': {'emoji': ' 🚶 ', 'tags': []},
              ':walking_woman:': {'emoji': ' 🚶\u200d♀ ', 'tags': []},
              ':wallis_futuna:': {'emoji': ' 🇼🇫 ', 'tags': []},
              ':waning_crescent_moon:': {'emoji': ' 🌘 ', 'tags': []},
              ':waning_gibbous_moon:': {'emoji': ' 🌖 ', 'tags': []},
              ':warning:': {'emoji': ' ⚠️ ', 'tags': ['wip']},
              ':wastebasket:': {'emoji': ' 🗑 ', 'tags': ['trash']},
              ':watch:': {'emoji': ' ⌚️ ', 'tags': ['time']},
              ':water_buffalo:': {'emoji': ' 🐃 ', 'tags': []},
              ':watermelon:': {'emoji': ' 🍉 ', 'tags': []},
              ':wave:': {'emoji': ' 👋 ', 'tags': ['goodbye']},
              ':wavy_dash:': {'emoji': ' 〰️ ', 'tags': []},
              ':waxing_crescent_moon:': {'emoji': ' 🌒 ', 'tags': []},
              ':waxing_gibbous_moon:': {'emoji': ' 🌔 ', 'tags': []},
              ':wc:': {'emoji': ' 🚾 ', 'tags': ['toilet', 'restroom']},
              ':weary:': {'emoji': ' 😩 ', 'tags': ['tired']},
              ':wedding:': {'emoji': ' 💒 ', 'tags': ['marriage']},
              ':weight_lifting_man:': {'emoji': ' 🏋 ', 'tags': ['gym', 'workout']},
              ':weight_lifting_woman:': {'emoji': ' 🏋️\u200d♀️ ',
                                         'tags': ['gym', 'workout']},
              ':western_sahara:': {'emoji': ' 🇪🇭 ', 'tags': []},
              ':whale2:': {'emoji': ' 🐋 ', 'tags': []},
              ':whale:': {'emoji': ' 🐳 ', 'tags': ['sea']},
              ':wheel_of_dharma:': {'emoji': ' ☸️ ', 'tags': []},
              ':wheelchair:': {'emoji': ' ♿️ ', 'tags': ['accessibility']},
              ':white_check_mark:': {'emoji': ' ✅ ', 'tags': []},
              ':white_circle:': {'emoji': ' ⚪️ ', 'tags': []},
              ':white_flag:': {'emoji': ' 🏳️ ', 'tags': []},
              ':white_flower:': {'emoji': ' 💮 ', 'tags': []},
              ':white_large_square:': {'emoji': ' ⬜️ ', 'tags': []},
              ':white_medium_small_square:': {'emoji': ' ◽️ ', 'tags': []},
              ':white_medium_square:': {'emoji': ' ◻️ ', 'tags': []},
              ':white_small_square:': {'emoji': ' ▫️ ', 'tags': []},
              ':white_square_button:': {'emoji': ' 🔳 ', 'tags': []},
              ':wilted_flower:': {'emoji': ' \U0001f940 ', 'tags': []},
              ':wind_chime:': {'emoji': ' 🎐 ', 'tags': []},
              ':wind_face:': {'emoji': ' 🌬 ', 'tags': []},
              ':wine_glass:': {'emoji': ' 🍷 ', 'tags': []},
              ':wink:': {'emoji': ' 😉 ', 'tags': ['flirt']},
              ':wolf:': {'emoji': ' 🐺 ', 'tags': []},
              ':woman:': {'emoji': ' 👩 ', 'tags': ['girls']},
              ':woman_artist:': {'emoji': ' 👩\u200d🎨 ', 'tags': ['painter']},
              ':woman_astronaut:': {'emoji': ' 👩\u200d🚀 ', 'tags': ['space']},
              ':woman_cartwheeling:': {'emoji': ' \U0001f938\u200d♀ ', 'tags': []},
              ':woman_cook:': {'emoji': ' 👩\u200d🍳 ', 'tags': ['chef']},
              ':woman_facepalming:': {'emoji': ' \U0001f926\u200d♀ ', 'tags': []},
              ':woman_factory_worker:': {'emoji': ' 👩\u200d🏭 ', 'tags': []},
              ':woman_farmer:': {'emoji': ' 👩\u200d🌾 ', 'tags': []},
              ':woman_firefighter:': {'emoji': ' 👩\u200d🚒 ', 'tags': []},
              ':woman_health_worker:': {'emoji': ' 👩\u200d⚕ ', 'tags': ['doctor', 'nurse']},
              ':woman_judge:': {'emoji': ' 👩\u200d⚖ ', 'tags': ['justice']},
              ':woman_juggling:': {'emoji': ' \U0001f939\u200d♀ ', 'tags': []},
              ':woman_mechanic:': {'emoji': ' 👩\u200d🔧 ', 'tags': []},
              ':woman_office_worker:': {'emoji': ' 👩\u200d💼 ', 'tags': ['business']},
              ':woman_pilot:': {'emoji': ' 👩\u200d✈ ', 'tags': []},
              ':woman_playing_handball:': {'emoji': ' \U0001f93e\u200d♀ ', 'tags': []},
              ':woman_playing_water_polo:': {'emoji': ' \U0001f93d\u200d♀ ', 'tags': []},
              ':woman_scientist:': {'emoji': ' 👩\u200d🔬 ', 'tags': ['research']},
              ':woman_shrugging:': {'emoji': ' \U0001f937\u200d♀ ', 'tags': []},
              ':woman_singer:': {'emoji': ' 👩\u200d🎤 ', 'tags': ['rockstar']},
              ':woman_student:': {'emoji': ' 👩\u200d🎓 ', 'tags': ['graduation']},
              ':woman_teacher:': {'emoji': ' 👩\u200d🏫 ', 'tags': ['school', 'professor']},
              ':woman_technologist:': {'emoji': ' 👩\u200d💻 ', 'tags': ['coder']},
              ':woman_with_turban:': {'emoji': ' 👳\u200d♀ ', 'tags': []},
              ':womans_clothes:': {'emoji': ' 👚 ', 'tags': []},
              ':womans_hat:': {'emoji': ' 👒 ', 'tags': []},
              ':women_wrestling:': {'emoji': ' \U0001f93c\u200d♀ ', 'tags': []},
              ':womens:': {'emoji': ' 🚺 ', 'tags': []},
              ':world_map:': {'emoji': ' 🗺 ', 'tags': ['travel']},
              ':worried:': {'emoji': ' 😟 ', 'tags': ['nervous']},
              ':wrench:': {'emoji': ' 🔧 ', 'tags': ['tool']},
              ':writing_hand:': {'emoji': ' ✍️ ', 'tags': []},
              ':x:': {'emoji': ' ❌ ', 'tags': []},
              ':yellow_heart:': {'emoji': ' 💛 ', 'tags': []},
              ':yemen:': {'emoji': ' 🇾🇪 ', 'tags': []},
              ':yen:': {'emoji': ' 💴 ', 'tags': []},
              ':yin_yang:': {'emoji': ' ☯️ ', 'tags': []},
              ':yum:': {'emoji': ' 😋 ', 'tags': ['tongue', 'lick']},
              ':zambia:': {'emoji': ' 🇿🇲 ', 'tags': []},
              ':zap:': {'emoji': ' ⚡️ ', 'tags': ['lightning', 'thunder']},
              ':zero:': {'emoji': ' 0️⃣ ', 'tags': []},
              ':zimbabwe:': {'emoji': ' 🇿🇼 ', 'tags': []},
              ':zipper_mouth_face:': {'emoji': ' 🤐 ', 'tags': ['silence', 'hush']},
              ':zzz:': {'emoji': ' 💤 ', 'tags': ['sleeping']}}



# DO NOT abuse this, meant for dev purposes, you should deploy your own deepmoji not hijack the demo site


def get_emoji_scores(text):
    params = {"q": text}
    emojis = {}
    scores = requests.get("https://deepmoji.mit.edu/api/", params=params).json()["scores"]
    for idx, score in enumerate(scores):
        if score:
            emojis[idx] = score
    return emojis


def get_emojis(text):
    params = {"q": text}
    emojis = {}
    scores = requests.get("https://deepmoji.mit.edu/api/", params=params).json()["scores"]
    for idx, score in enumerate(scores):
        if score:
            emojis[idx] = score
    scores = sorted(emojis, key=lambda k: emojis[k])
    scores.reverse()
    return [DEEPMOJI_MAP[s] for s in scores]


def get_emotions(text):
    params = {"q": text}
    emojis = {}
    scores = requests.get("https://deepmoji.mit.edu/api/", params=params).json()["scores"]
    for idx, score in enumerate(scores):
        if score:
            emojis[idx] = score
    scores = sorted(emojis, key=lambda k: emojis[k])
    scores.reverse()
    emos = []
    for s in scores:
        if EMOJI_TO_EMOTION[s] not in emos:
            emos.append((EMOJI_TO_EMOTION[s], s))
    return emos


