# the data structures here are the raw data from where this module was built
# the structures actually used were expanded and modified to solve incompatibilities


# https://en.wikipedia.org/wiki/Contrasting_and_categorization_of_emotions#Contrasting_basic_emotions
EMOTION_CONTRASTS = {"related to object properties":
                         ["interest", "curiosity", "enthusiasm", "indifference", "habituation", "boredom",
                          "attraction", "desire", "admiration", "aversion", "disgust", "revulsion",
                          "surprise", "amusement", "alarm", "panic"],
                     'future appraisal': ["hope", "excitement", "fear", "anxiety", "dread"],
                     'event related': ["gratitude", "thankfulness", "anger", "rage", "joy", "elation", "triumph",
                                       "jubilation", "sorrow", "grief", "patience", "frustration", "disappointment",
                                       "contentment", "discontentment", "restlessness"],
                 'self appraisal': ["humility", "modesty", "pride", "arrogance"],
                 'social': ["charity", "sympathy", "avarice", "greed", "miserliness", "envy", "jealousy",
                                "cruelty"],
                 'cathected': ["love", "hate"],
                 }

POSITIVE = ["interest", "curiosity", "enthusiasm", "amusement",
            "attraction", "desire", "admiration", "surprise", "love",
            "hope", "excitement", "gratitude", "thankfulness",
            "joy", "elation", "triumph", "jubilation", "patience",
            "contentment", "humility", "modesty", "charity", "sympathy"]
NEGATIVE = ["indifference", "habituation", "boredom", "aversion",
            "disgust", "revulsion", "alarm", "panic", "fear", "anxiety",
            "dread", "anger", "rage", "sorrow", "grief", "frustration",
            "disappointment", "pride", "arrogance", "avarice", "greed",
            "miserliness", "envy", "jealousy", "cruelty", "hate"]

HUMAINE_EARL = {
    "negative and forceful":
        ["anger", "annoyance", "contempt", "disgust", "irritation"],
    "negative and passive":
        ["boredom", "despair", "disappointment", "hurt", "sadness"],
    "caring":
        ["affection", "empathy", "friendliness", "love"],
    "negative and not in control":
        ["Anxiety", "Embarrassment", "fear", "Helplessness", "Powerlessness", "Worry"],
    "agitation":
        ["Stress", "Shock", "Tension"],
    "positive thoughts":
        ["Courage", "Hope", "Humility", "Satisfaction", "Trust"],
    "negative thoughts":
        ["Pride", "Doubt", "Envy", "Frustration", "Guilt", "Shame"],
    "positive and lively":
        ["Amusement", "Delight", "Elation", "Excitement", "Happiness", "Joy", "Pleasure"],
    "quiet positive":
        ["Calmness", "Contentment", "Relaxation", "Relief", "Serenity"],
    "reactive":
        ["Interest", "Politeness", "Surprise"]
}

# NOTE Parrott's emotions by groups contains some "loops", these maybe should filtered
# NOTE in Parrott's emotions by groups disgust is part of anger, but not according to Plutchik's
PARROTT_GROUPS = {
    'anger': [{'disgust': ['revulsion',
                           'contempt',
                           'loathing'],
               'envy': ['jealousy'],
               'exasperation': ['frustration'],
               'irritability': ['aggravation',
                                'agitation',
                                'annoyance',
                                'grouchy',
                                'grumpy',
                                'crosspatch'],
               'rage': ['outrage',
                        'fury',
                        'wrath',
                        'hostility',
                        'ferocity',
                        'bitterness',
                        'hate',
                        'scorn',
                        'spite',
                        'vengefulness',
                        'anger',  # loop!
                        'dislike',
                        'resentment'],
               'torment': ['torment']}],  # loop!
    'fear': [{'horror': ['alarm',
                         'shock',
                         'fright',
                         'horror',  # loop!
                         'fear',  # loop!
                         'terror',
                         'panic',
                         'hysteria',
                         'mortification'],
              'nervousness': ['anxiety',
                              'suspense',
                              'uneasiness',
                              'apprehension',
                              'worry',
                              'distress',
                              'dread']}],
    'joy': [{'cheerfulness': ['amusement',
                              'bliss',
                              'gaiety',
                              'glee',
                              'jolliness',
                              'joviality',
                              'joy',  # loop!
                              'delight',
                              'enjoyment',
                              'gladness',
                              'happiness',
                              'jubilation',
                              'elation',
                              'satisfaction',
                              'ecstasy',
                              'euphoria'],
             'contentment': ['pleasure'],
             'enthrallment': ['rapture',
                              'enthrallment'],  # loop!
             'optimism': ['eagerness',
                          'hope'],
             'pride': ['triumph'],
             'relief': ['relief'],  # loop!
             'zest': ['enthusiasm',
                      'zeal',
                      'excitement',
                      'thrill',
                      'exhilaration']}],
    'love': [{'affection': ['adoration',
                            'fondness',
                            'liking',
                            'attraction',
                            'caring',
                            'tenderness',
                            'compassion',
                            'sentimentality'],
              'longing': ['longing'],  # loop!
              'lust': ['desire',
                       'passion',
                       'infatuation']}],
    'sadness': [{'disappointment': ['dismay',
                                    'displeasure'],
                 'misery': ['depression',
                            'despair',
                            'gloom',
                            'glumness',
                            'unhappiness',
                            'grief',
                            'sorrow',
                            'woe',
                            'melancholy'],
                 'neglect': ['alienation',
                             'defeatism',
                             'dejection',
                             'embarrassment',
                             'homesickness',
                             'humiliation',
                             'insecurity',
                             'insult',
                             'isolation',
                             'loneliness',
                             'rejection'],
                 'shame': ['guilt',
                           'regret',
                           'remorse'],
                 'suffering': ['agony',
                               'anguish',
                               'hurt'],
                 'sympathy': ['pity',
                              'sympathy',  # loop!
                              'mono no aware']}],
    'surprise': [{'amazement': [],
                  'astonishment': []}]
}

FIXED_PARROT_GROUP = {
    'disgust': [{'revulsion': []}, {'contempt': []}, {'loathing': []}],
    'anger': [{
        'envy': ['jealousy'],
        'exasperation': ['frustration'],
        'irritability': ['aggravation',
                         'agitation',
                         'annoyance',
                         'grouchy',
                         'grumpy',
                         'crosspatch'],
        'rage': ['outrage',
                 'fury',
                 'wrath',
                 'hostility',
                 'ferocity',
                 'bitterness',
                 'hate',
                 'scorn',
                 'spite',
                 'vengefulness',
                 'dislike',
                 'resentment'],
        'torment': []}],
    'fear': [{'horror': ['alarm',
                         'shock',
                         'fright',
                         'terror',
                         'panic',
                         'hysteria',
                         'mortification'],
              'nervousness': ['anxiety',
                              'suspense',
                              'uneasiness',
                              'apprehension',
                              'worry',
                              'distress',
                              'dread']}],
    'joy': [{'cheerfulness': ['amusement',
                              'bliss',
                              'gaiety',
                              'glee',
                              'jolliness',
                              'joviality',
                              'delight',
                              'enjoyment',
                              'gladness',
                              'happiness',
                              'jubilation',
                              'elation',
                              'satisfaction',
                              'ecstasy',
                              'euphoria'],
             'contentment': ['pleasure'],
             'enthrallment': ['rapture'],
             'optimism': ['eagerness',
                          'hope'],
             'pride': ['triumph'],
             'relief': [],
             'zest': ['enthusiasm',
                      'zeal',
                      'excitement',
                      'thrill',
                      'exhilaration']}],
    'love': [{'affection': ['adoration',
                            'fondness',
                            'liking',
                            'attraction',
                            'caring',
                            'tenderness',
                            'compassion',
                            'sentimentality'],
              'longing': [],
              'lust': ['desire',
                       'passion',
                       'infatuation']}],
    'sadness': [{'disappointment': ['dismay',
                                    'displeasure'],
                 'misery': ['depression',
                            'despair',
                            'gloom',
                            'glumness',
                            'unhappiness',
                            'grief',
                            'sorrow',
                            'woe',
                            'melancholy'],
                 'neglect': ['alienation',
                             'defeatism',
                             'dejection',
                             'embarrassment',
                             'homesickness',
                             'humiliation',
                             'insecurity',
                             'insult',
                             'isolation',
                             'loneliness',
                             'rejection'],
                 'shame': ['guilt',
                           'regret',
                           'remorse'],
                 'suffering': ['agony',
                               'anguish',
                               'hurt'],
                 'sympathy': ['pity',
                              'mono no aware']}],
    'surprise': [{'amazement': [],
                  'astonishment': []}]
}
